@@ -21,7 +21,10 @@ import GemRB
 from GUIDefines import *
 from ie_stats import *
 from ie_restype import RES_2DA
+from ie_slots import *
+import GameCheck
 import GUICommon
+import Spellbook
 import CommonTables
 import LUSpellSelection
 import LUProfsSelection
@@ -103,7 +106,7 @@ def DualClassWindow ():
 
 	# back button (on)
 	DCMainBackButton = DCMainWindow.GetControl (5)
-	if GUICommon.GameIsBG2():
+	if GameCheck.IsBG2():
 		DCMainBackButton.SetText (15416)
 	DCMainBackButton.SetEvent (IE_GUI_BUTTON_ON_PRESS, DCMainBackPress)
 	DCMainBackButton.SetState (IE_GUI_BUTTON_ENABLED)
@@ -125,7 +128,7 @@ def DualClassWindow ():
 
 	# class name
 	Kit = GUICommon.GetKitIndex (pc)
-	OldClassName = CommonTables.Classes.GetRowName (CommonTables.Classes.FindValue (5, GemRB.GetPlayerStat (pc, IE_CLASS) ) )
+	OldClassName = GUICommon.GetClassRowName (pc)
 	if Kit:
 		OldKitName = CommonTables.KitList.GetValue (Kit, 0, 0)
 	else:
@@ -148,6 +151,7 @@ def DCMainDonePress ():
 	This de-activates our old class and readjusts the basic actor stats, such as
 	THAC0, spell casting, proficiencies, and so forth, to the new class."""
 	import GUIREC
+	global ClassName
 
 	# save our proficiencies
 	LUProfsSelection.ProfsSave (pc, LUProfsSelection.LUPROFS_TYPE_DUALCLASS)
@@ -165,7 +169,7 @@ def DCMainDonePress ():
 	if not NewMageSpells:
 		for i in range (9):
 			GemRB.SetMemorizableSpellsCount (pc, 0, IE_SPELL_TYPE_WIZARD, i)
-	GUICommon.RemoveKnownSpells (pc, IE_SPELL_TYPE_PRIEST, 1,7, 1)
+	Spellbook.RemoveKnownSpells (pc, IE_SPELL_TYPE_PRIEST, 1,7, 1)
 
 	# apply our class abilities
 	ABTable = CommonTables.ClassSkills.GetValue (ClassName, "ABILITIES")
@@ -174,7 +178,7 @@ def DCMainDonePress ():
 
 	# learn our new priest spells
 	if NewPriestMask:
-		GUICommon.LearnPriestSpells (pc, 1, NewPriestMask)
+		Spellbook.LearnPriestSpells (pc, 1, NewPriestMask)
 		GemRB.SetMemorizableSpellsCount (pc, 1, IE_SPELL_TYPE_PRIEST, 0)
 
 	# save our thief skills if we have them
@@ -183,8 +187,9 @@ def DCMainDonePress ():
 	# save our new class and say was multi
 	OldClassId = GemRB.GetPlayerStat (pc, IE_CLASS)
 	MultClassId = (1 << (NewClassId-1)) | (1 << (OldClassId-1))
-	MultClassId = CommonTables.Classes.FindValue (4, MultClassId)
-	MultClassId = CommonTables.Classes.GetValue (MultClassId, 5)
+	MultClassId = CommonTables.Classes.FindValue ("MULTI", MultClassId)
+	MultClassId = CommonTables.Classes.GetRowName (MultClassId)
+	MultClassId = CommonTables.Classes.GetValue (MultClassId, "ID")
 	GemRB.SetPlayerStat (pc, IE_CLASS, MultClassId)
 	GemRB.SetPlayerStat (pc, IE_MC_FLAGS, CommonTables.Classes.GetValue (OldClassName, "MC_WAS_ID", 1))
 
@@ -201,11 +206,27 @@ def DCMainDonePress ():
 	GemRB.SetPlayerStat (pc, IE_TOHIT, ThacoTable.GetValue (NewClassId-1, 0, 1))
 
 	# new saves
-	SavesTable = CommonTables.Classes.GetValue (CommonTables.Classes.FindValue (5, NewClassId), 3, 0)
+	SavesTable = CommonTables.Classes.GetValue (ClassName, "SAVE", 0)
 	SavesTable = GemRB.LoadTable (SavesTable)
 	for i in range (5):
 		GemRB.SetPlayerStat (pc, IE_SAVEVSDEATH+i, SavesTable.GetValue (i, 0))
 
+	# dump any equipped items that are now unusable
+	SlotTypes = [ SLOT_ARMOUR, SLOT_SHIELD, SLOT_HELM, SLOT_RING, SLOT_CLOAK, SLOT_BOOT, SLOT_AMULET, SLOT_GLOVE, SLOT_BELT, SLOT_ITEM, SLOT_WEAPON, SLOT_QUIVER ]
+	for type in SlotTypes:
+		Slots = GemRB.GetSlots (pc, type)
+		if not len(Slots):
+			# nothing there
+			continue
+		for slot in Slots:
+			SlotType = GemRB.GetSlotType (slot, pc)
+			CREItem = GemRB.GetSlotItem (pc, slot)
+			if not GemRB.CanUseItemType (SlotType["Type"], CREItem["ItemResRef"], pc):
+				# move it to a free inventory slot by mimicking dragging
+				Item = GemRB.GetItem (CREItem["ItemResRef"])
+				GemRB.DragItem (pc, slot, Item["ItemIcon"])
+				GemRB.DropDraggedItem (pc, -3)
+
 	# close our window
 	if DCMainWindow:
 		DCMainWindow.Unload ()
@@ -245,7 +266,7 @@ def DCMainBackPress ():
 
 		# un-learn our spells and skills
 		if NewMageSpells:
-			GUICommon.RemoveKnownSpells (pc, IE_SPELL_TYPE_WIZARD, 1,1, 1)
+			Spellbook.RemoveKnownSpells (pc, IE_SPELL_TYPE_WIZARD, 1,1, 1)
 
 		LUSkillsSelection.SkillsNullify ()
 		NewPriestMask = 0
@@ -382,10 +403,9 @@ def CanDualInto (index):
 
 	# make sure we aren't restricted by alignment
 	AlignmentTable = GemRB.LoadTable ("alignmnt")
-	AlignsTable = GemRB.LoadTable ("aligns")
 	Alignment = GemRB.GetPlayerStat (pc, IE_ALIGNMENT) # our alignment
-	Alignment = AlignsTable.FindValue (3, Alignment)
-	Alignment = AlignsTable.GetValue (Alignment, 4) # convert the alignment
+	Alignment = CommonTables.Aligns.FindValue (3, Alignment)
+	Alignment = CommonTables.Aligns.GetValue (Alignment, 4) # convert the alignment
 	if not AlignmentTable.GetValue (DCClasses[index], Alignment, 1): # check it
 		return 0
 
@@ -430,7 +450,7 @@ def DCOpenProfsWindow ():
 	# load up our window and set some basic variables
 	DCProfsWindow = GemRB.LoadWindow (15)
 	NewClassId = CommonTables.Classes.GetValue (ClassName, "ID", 1)
-	if GUICommon.GameIsBG2():
+	if GameCheck.IsBG2():
 		LUProfsSelection.SetupProfsWindow (pc, \
 			LUProfsSelection.LUPROFS_TYPE_DUALCLASS, DCProfsWindow, DCProfsRedraw, classid=NewClassId)
 	else:
@@ -497,7 +517,7 @@ def DCProfsDonePress ():
 			NewPriestMask = 0x4000
 	elif DruidTable != "*":
 		# make sure we can cast spells at this level (rangers)
-		if GUICommon.HasTOB ():
+		if GameCheck.HasTOB ():
 			DruidTable = GemRB.LoadTable (DruidTable)
 			if DruidTable.GetRowName (0) == "1":
 				NewPriestMask = 0x8000
@@ -534,7 +554,7 @@ def OpenSkillsWindow ():
 	global DCSkillsWindow, DCSkillsDoneButton
 
 	DCSkillsWindow = GemRB.LoadWindow (7)
-	if GUICommon.GameIsBG2():
+	if GameCheck.IsBG2():
 		LUSkillsSelection.SetupSkillsWindow (pc, \
 			LUSkillsSelection.LUSKILLS_TYPE_DUALCLASS, DCSkillsWindow, DCSkillsRedraw, classid=NewClassId)
 	else:
