@@ -1141,7 +1141,7 @@ def GetActorPortrait (actor, which):
 
 
 def UpdateAnimation ():
-	if not GemRB.HasResource ("ANIMS", RES_2DA):
+	if not GemRB.HasResource ("ANIMS", RES_2DA, 1):
 		# FIXME: make a simpler version for non-pst too
 		# this is a callback from the core on EF_UPDATEANIM!
 		return
@@ -1163,8 +1163,8 @@ def UpdateAnimation ():
 				animid = item["AnimationType"]
 
 	BioTable = GemRB.LoadTable ("BIOS")
-	Specific = "%d"%GemRB.GetPlayerStat (pc, IE_SPECIFIC)
-	AvatarName = BioTable.GetValue (Specific, "PC")
+	Specific = GemRB.GetPlayerStat (pc, IE_SPECIFIC)
+	AvatarName = BioTable.GetRowName (Specific+1)
 	AnimTable = GemRB.LoadTable ("ANIMS")
 	if animid=="":
 		animid="*"
@@ -1176,13 +1176,9 @@ def UpdateAnimation ():
 
 # NOTE: the following 4 functions are only used in iwd2
 def GetActorRaceTitle (actor):
-	RaceID = GemRB.GetPlayerStat (actor, IE_SUBRACE)
-	if RaceID:
-		RaceID += GemRB.GetPlayerStat (actor, IE_RACE)<<16
-	else:
-		RaceID = GemRB.GetPlayerStat (actor, IE_RACE)
-	row = CommonTables.Races.FindValue (3, RaceID )
-	RaceTitle = CommonTables.Races.GetValue (row, 2)
+	import IDLUCommon
+	RaceIndex = IDLUCommon.GetRace (actor)
+	RaceTitle = CommonTables.Races.GetValue (RaceIndex, 2)
 	return RaceTitle
 
 # NOTE: this function is called with the primary classes
