@@ -19,9 +19,10 @@
 # code shared between the common GUIREC and that of iwd2 (pst)
 import GemRB
 import GameCheck
+import GUICommon
 import Portrait
 from GUIDefines import *
-from ie_stats import IE_SEX, IE_CLASS, IE_MC_FLAGS, MC_EXPORTABLE
+from ie_stats import IE_SEX, IE_CLASS, IE_RACE, IE_MC_FLAGS, MC_EXPORTABLE
 from ie_restype import RES_WAV
 
 BiographyWindow = None
@@ -31,6 +32,7 @@ SubSubCustomizeWindow = None
 ExportWindow = None
 NameField = ExportDoneButton = None
 ScriptsTable = None
+RevertButton = None
 
 if GameCheck.IsBG2() or GameCheck.IsBG1():
 	BioStrRefSlot = 74
@@ -444,20 +446,22 @@ def UpdateScriptSelection():
 
 def RevertBiography():
 	global BioStrRef
+	global RevertButton
 
 	if GameCheck.IsIWD2():
 		BioTable = GemRB.LoadTable ("bios")
 		pc = GemRB.GameGetSelectedPCSingle ()
-		Class = GemRB.GetPlayerStat (pc, IE_CLASS)
-		BioStrRef = BioTable.GetValue(Class,1) # TODO: check if it is really class ordered and what happens for multiclassed chars
+		ClassName = GUICommon.GetClassRowName (pc)
+		BioStrRef = BioTable.GetValue (ClassName, "BIO")
 	else:
 		BioStrRef = 33347
 	TextArea.SetText (BioStrRef)
-	CloseSubCustomizeWindow ()
+	RevertButton.SetState (IE_GUI_BUTTON_DISABLED)
 	return
 
 def OpenBiographyEditWindow ():
 	global SubCustomizeWindow
+	global RevertButton
 	global BioStrRef
 	global TextArea
 
@@ -467,7 +471,7 @@ def OpenBiographyEditWindow ():
 	if BioStrRef != 33347:
 		Changed = 1
 
-	# TODO: check if this is really needed
+	# 23 and 24 were deleted and replaced in iwd
 	if GameCheck.IsIWD1() or GameCheck.IsIWD2():
 		SubCustomizeWindow = GemRB.LoadWindow (51)
 	else:
@@ -483,8 +487,10 @@ def OpenBiographyEditWindow ():
 	DoneButton.SetText (11973)
 	DoneButton.SetFlags (IE_GUI_BUTTON_DEFAULT, OP_OR)
 
+	ScrollbarID = 6
 	if GameCheck.IsIWD1() or GameCheck.IsIWD2():
 		RevertButton = SubCustomizeWindow.GetControl (6)
+		ScrollbarID = 3
 	else:
 		RevertButton = SubCustomizeWindow.GetControl (3)
 	RevertButton.SetText (2240)
@@ -496,7 +502,7 @@ def OpenBiographyEditWindow ():
 	CancelButton.SetFlags (IE_GUI_BUTTON_CANCEL, OP_OR)
 
 	TextArea = SubCustomizeWindow.GetControl (4)
-	TextArea.SetBufferLength (65535)
+	TextArea = TextArea.ConvertEdit (ScrollbarID)
 	TextArea.SetText (BioStrRef)
 
 	ClearButton.SetEvent (IE_GUI_BUTTON_ON_PRESS, ClearBiography)
@@ -505,23 +511,26 @@ def OpenBiographyEditWindow ():
 	CancelButton.SetEvent (IE_GUI_BUTTON_ON_PRESS, CloseSubCustomizeWindow)
 
 	SubCustomizeWindow.ShowModal (MODAL_SHADOW_GRAY)
+	TextArea.SetStatus (IE_GUI_CONTROL_FOCUSED) # DO NOT MOVE near the rest of TextArea handling
 	return
 
 def ClearBiography():
+	global BioStrRef
+	global RevertButton
+
 	pc = GemRB.GameGetSelectedPCSingle ()
+	#pc is 1 based
 	BioStrRef = 62015+pc
-	#GemRB.CreateString (BioStrRef, "")
 	TextArea.SetText ("")
+	RevertButton.SetState (IE_GUI_BUTTON_ENABLED)
 	return
 
 def DoneBiographyWindow ():
 	global BioStrRef
 
-	#TODO set bio
 	pc = GemRB.GameGetSelectedPCSingle ()
-	#pc is 1 based
-	BioStrRef = 62015+pc
-	GemRB.CreateString (BioStrRef, TextArea.QueryText())
+	if BioStrRef != 33347:
+		GemRB.CreateString (BioStrRef, TextArea.QueryText())
 	GemRB.SetPlayerString (pc, BioStrRefSlot, BioStrRef)
 	CloseSubCustomizeWindow ()
 	return
@@ -537,7 +546,10 @@ def OpenBiographyWindow ():
 
 	TextArea = Window.GetControl (0)
 	pc = GemRB.GameGetSelectedPCSingle ()
-	TextArea.SetText (GemRB.GetPlayerString (pc, BioStrRefSlot) )
+	if GameCheck.IsBG1 () and GemRB.GetPlayerName (pc, 2) == 'none':
+		TextArea.SetText (GetProtagonistBiography (pc))
+	else:
+		TextArea.SetText (GemRB.GetPlayerString (pc, BioStrRefSlot))
 
 	# Done
 	Button = Window.GetControl (2)
@@ -562,6 +574,17 @@ def CloseBiographyWindow ():
 			GUIREC.InformationWindow.SetVisible (WINDOW_VISIBLE)
 	return
 
+def GetProtagonistBiography (pc):
+	BioTable = GemRB.LoadTable ("bios")
+	racestrings = [ 15895, 15891, 15892, 15890, 15893, 15894 ]
+
+	ClassName = GUICommon.GetClassRowName (pc)
+	bio = GemRB.GetString (BioTable.GetValue (ClassName, "BIO"))
+	race = GemRB.GetPlayerStat (pc, IE_RACE)
+	if race <= 6:
+		bio += "\n\n" + GemRB.GetString (racestrings[race-1])
+	return bio
+
 def OpenExportWindow ():
 	global ExportWindow, NameField, ExportDoneButton
 
