@@ -777,9 +777,6 @@ def OpenItemWindow ():
 def DialogItemWindow ():
 	"""Converse with an item."""
 
-	if ItemInfoWindow:
-		ItemInfoWindow.Unload ()
-	GUIINV.OpenInventoryWindow ()
 	pc = GemRB.GameGetSelectedPCSingle ()
 	if GameCheck.IsPST():
 		slot, slot_item = GUIINV.ItemHash[GemRB.GetVar ('ItemButton')]
@@ -789,6 +786,9 @@ def DialogItemWindow ():
 	ResRef = slot_item['ItemResRef']
 	item = GemRB.GetItem (ResRef)
 	dialog=item["Dialog"]
+	if ItemInfoWindow:
+		ItemInfoWindow.Unload ()
+	GUIINV.OpenInventoryWindow ()
 	GemRB.ExecuteString ("StartDialogOverride(\""+dialog+"\",Myself,0,0,1)", pc)
 	return
 
@@ -827,11 +827,13 @@ def IdentifyUseScroll ():
 	return
 
 def CloseIdentifyItemWindow ():
-	global ItemIdentifyWindow
+	global ItemIdentifyWindow, ItemInfoWindow
 
 	if ItemIdentifyWindow:
 		ItemIdentifyWindow.Unload ()
 		ItemIdentifyWindow = None
+	if ItemInfoWindow:
+		ItemInfoWindow.ShowModal (MODAL_SHADOW_GRAY)
 	return
 
 def IdentifyItemWindow ():
@@ -882,11 +884,13 @@ def DoneAbilitiesItemWindow ():
 	return
 
 def CloseAbilitiesItemWindow ():
-	global ItemAbilitiesWindow
+	global ItemAbilitiesWindow, ItemInfoWindow
 
 	if ItemAbilitiesWindow:
 		ItemAbilitiesWindow.Unload ()
 		ItemAbilitiesWindow = None
+	if ItemInfoWindow:
+		ItemInfoWindow.ShowModal (MODAL_SHADOW_GRAY)
 	return
 
 def AbilitiesItemWindow ():
