@@ -66,10 +66,11 @@ def OnLoad():
 	# apply class/kit abilities
 	GUICommon.ResolveClassAbilities (MyChar, ClassName)
 
-	# apply starting (alignment dictated) abilities
-	# pc, table, new level, level diff, alignment
-	AlignmentAbbrev = CommonTables.Aligns.FindValue (3, GemRB.GetPlayerStat (MyChar, IE_ALIGNMENT))
-	GUICommon.AddClassAbilities (MyChar, "abstart", 6,6, AlignmentAbbrev)
+	# alignment based bhaal powers are added in FixInnates later
+	# unless we're starting with SoA
+	if GemRB.GetVar("oldgame") == 1:
+		AlignmentAbbrev = CommonTables.Aligns.FindValue ("VALUE", GemRB.GetPlayerStat (MyChar, IE_ALIGNMENT))
+		GUICommon.AddClassAbilities (MyChar, "abstart", 6,6, AlignmentAbbrev)
 
 	# setup starting gold (uses a roll dictated by class
 	TmpTable = GemRB.LoadTable ("strtgold")
@@ -94,6 +95,14 @@ def OnLoad():
 	SmallPortrait = GemRB.GetToken ("SmallPortrait")
 	GemRB.FillPlayerInfo (MyChar, LargePortrait, SmallPortrait)
 
+	# biography
+	Bio = GemRB.GetToken("BIO")
+	BioStrRef = 33347
+	if Bio:
+		BioStrRef = 62016
+		GemRB.CreateString (BioStrRef, Bio)
+	GemRB.SetPlayerString (MyChar, 74, BioStrRef)
+
 	if GameCheck.IsTOB():
 		# will also add the starting inventory for tob
 		GemRB.GameSetExpansion (4)
@@ -196,8 +205,4 @@ def GiveEquipment(MyChar, ClassName, KitIndex):
  			GemRB.ChangeItemFlag (MyChar, targetslot, IE_INV_ITEM_IDENTIFIED, OP_OR)
 			inventory_exclusion |= item['Exclusion']
 
-		# grant the slayer change ability to the protagonist
-		if MyChar == 1:
-			GemRB.LearnSpell (MyChar, "SPIN822", LS_MEMO)
 		return
-		
