@@ -18,14 +18,33 @@
 #
 #ToB start window, precedes the SoA window
 import GemRB
-import GUICommon
+import GameCheck
+
+try:
+	import os
+except ImportError:
+	print "No os module, skipping test"
+	os = None
 
 StartWindow = 0
 
+def EndTest():
+	GemRB.QuitGame()
+	GemRB.Quit()
+	print "Game test completed"
+
 def OnLoad():
 	global StartWindow, skip_videos
 
-	GemRB.EnableCheatKeys(1)
+	# check if we're just running the game-entering test
+	if os and os.getenv('GEMRB_TEST', "0") != "0":
+		import threading
+		print "\nStarting game test"
+		GemRB.LoadGame(None)
+		GemRB.EnterGame()
+		# with delayed execution, more of the game files get loaded
+		threading.Timer(1, EndTest).start() # the 1s varies!
+
 	skip_videos = GemRB.GetVar ("SkipIntroVideos")
 	if not skip_videos and not GemRB.GetVar ("SeenIntroVideos"):
 		GemRB.PlayMovie ("BISLOGO", 1)
@@ -43,7 +62,7 @@ def OnLoad():
 		GemRB.LoadWindowFrame("STON10L", "STON10R", "STON10T", "STON10B")
 
 	#if not detected tob, we go right to the main menu
-	if not GUICommon.HasTOB():
+	if not GameCheck.HasTOB():
 		GemRB.SetMasterScript("BALDUR","WORLDMAP")
 		GemRB.SetVar("oldgame",1)
 		GemRB.SetNextScript("Start2")
