@@ -26,6 +26,8 @@ def OnLoad():
 	GemRB.SetPlayerStat (MyChar, IE_SEX, GemRB.GetVar ("Gender") )
 	GemRB.SetPlayerStat (MyChar, IE_RACE, GemRB.GetVar ("BaseRace") )
 	race = GemRB.GetVar ("Race")
+	if race == GemRB.GetVar ("BaseRace"):
+		race = 0 # no subrace
 	GemRB.SetPlayerStat (MyChar, IE_SUBRACE, race & 255 )
 	CharOverview.UpdateOverview(3)
 	return
