@@ -31,15 +31,15 @@
 #include <unistd.h>
 #endif
 
-//this supposed to convince SDL to work on OS/X
-//WARNING: commenting this out will cause SDL 1.2.x to crash
-#ifdef __APPLE_CC__ // we need startup SDL here
-#include <SDL.h>
-#endif
+using namespace GemRB;
 
 #ifdef ANDROID
-#include <SDL/SDL.h>
-#include "audio.h"
+#include <SDL.h>
+// if/when android moves to SDL 1.3 remove these special functions.
+// SDL 1.3 fires window events for these conditions that are handled in SDLVideo.cpp.
+// see SDL_WINDOWEVENT_MINIMIZED and SDL_WINDOWEVENT_RESTORED
+#if SDL_COMPILEDVERSION < SDL_VERSIONNUM(1,3,0)
+#include "Audio.h"
 
 // pause audio playing if app goes in background
 static void appPutToBackground()
@@ -51,11 +51,18 @@ static void appPutToForeground()
 {
   core->GetAudioDrv()->Resume();
 }
-
+#endif
 #endif
 
 int main(int argc, char* argv[])
 {
+#ifdef HAVE_SETENV
+	setenv("SDL_VIDEO_X11_WMCLASS", argv[0], 0);
+#	ifdef ANDROID
+		setenv("GEM_DATA", SDL_AndroidGetExternalStoragePath(), 1);
+#	endif
+#endif
+
 #ifdef M_TRIM_THRESHOLD
 // Prevent fragmentation of the heap by malloc (glibc).
 //
@@ -72,19 +79,26 @@ int main(int argc, char* argv[])
 #endif
 
 	Interface::SanityCheck(VERSION_GEMRB);
-	core = new Interface( argc, argv );
-	if (core->Init() == GEM_ERROR) {
+	InitializeLogging();
+
+	core = new Interface();
+	CFGConfig* config = new CFGConfig(argc, argv);
+	if (core->Init( config ) == GEM_ERROR) {
+		delete config;
 		delete( core );
-		print("Press enter to continue...");
-		textcolor(DEFAULT);
+		Log(MESSAGE, "Main", "Press enter to continue...");
 		getc(stdin);
+		ShutdownLogging();
 		return -1;
 	}
+	delete config;
 #ifdef ANDROID
+#if SDL_COMPILEDVERSION < SDL_VERSIONNUM(1,3,0)
     SDL_ANDROID_SetApplicationPutToBackgroundCallback(&appPutToBackground, &appPutToForeground);
+#endif
 #endif
 	core->Main();
 	delete( core );
-	textcolor(DEFAULT);
+	ShutdownLogging();
 	return 0;
 }
