@@ -23,6 +23,8 @@
 
 #include "Holder.h"
 
+namespace GemRB {
+
 class GEM_EXPORT Callback : public Held<Callback> {
 public:
 	virtual ~Callback();
@@ -32,4 +34,6 @@ public:
 
 typedef Holder<Callback> EventHandler;
 
+}
+
 #endif
