@@ -28,7 +28,11 @@
 #include "GUI/TextArea.h"
 #include "Scriptable/Actor.h"
 
-GEM_EXPORT DisplayMessage * displaymsg;
+#include <cstdarg>
+
+namespace GemRB {
+
+GEM_EXPORT DisplayMessage * displaymsg = NULL;
 
 static int strref_table[STRREF_COUNT];
 
@@ -69,9 +73,7 @@ void DisplayMessage::DisplayString(const char* Text, Scriptable *target) const
 		ta->AppendText( Text, -1 );
 	} else {
 		if(target) {
-			char *tmp = strdup(Text);
-
-			target->DisplayHeadText(tmp);
+			target->DisplayHeadText(Text);
 		}
 	}
 }
@@ -86,23 +88,26 @@ bool DisplayMessage::HasStringReference(int stridx) const
 	return strref_table[stridx] != -1;
 }
 
-unsigned int DisplayMessage::GetSpeakerColor(const char *&name, const Scriptable *&speaker) const
+unsigned int DisplayMessage::GetSpeakerColor(char *&name, const Scriptable *&speaker) const
 {
 	unsigned int speaker_color;
+	char *tmp;
 
 	if(!speaker) return 0;
 	switch (speaker->Type) {
 		case ST_ACTOR:
-			name = speaker->GetName(-1);
+			name = strdup(speaker->GetName(-1));
 			core->GetPalette( ((Actor *) speaker)->GetStat(IE_MAJOR_COLOR) & 0xFF, PALSIZE, ActorColor );
 			speaker_color = (ActorColor[4].r<<16) | (ActorColor[4].g<<8) | ActorColor[4].b;
 			break;
 		case ST_TRIGGER: case ST_PROXIMITY: case ST_TRAVEL:
-			name = core->GetString( speaker->DialogName );
+			tmp = core->GetString(speaker->DialogName);
+			name = strdup(tmp);
+			core->FreeString(tmp);
 			speaker_color = 0xc0c0c0;
 			break;
 		default:
-			name = "";
+			name = strdup("");
 			speaker_color = 0x800000;
 			break;
 	}
@@ -156,7 +161,7 @@ void DisplayMessage::DisplayConstantStringValue(int stridx, unsigned int color,
 void DisplayMessage::DisplayConstantStringNameString(int stridx, unsigned int color, int stridx2, const Scriptable *actor) const
 {
 	unsigned int actor_color;
-	const char *name = 0;
+	char *name = 0;
 
 	if (stridx<0) return;
 	actor_color = GetSpeakerColor(name, actor);
@@ -169,6 +174,7 @@ void DisplayMessage::DisplayConstantStringNameString(int stridx, unsigned int co
 	} else {
 		snprintf( newstr, newlen, DisplayFormatName, color, name, color, text );
 	}
+	free( name );
 	core->FreeString( text );
 	core->FreeString( text2 );
 	DisplayString( newstr );
@@ -187,13 +193,29 @@ void DisplayMessage::DisplayConstantStringName(int stridx, unsigned int color, c
 	core->FreeString(text);
 }
 
+//Treats the constant string as a numeric format string, otherwise like the previous method
+void DisplayMessage::DisplayConstantStringNameValue(int stridx, unsigned int color, const Scriptable *speaker, int value) const
+{
+	if (stridx<0) return;
+	if(!speaker) return;
+
+	char* text = core->GetString( strref_table[stridx], IE_STR_SOUND|IE_STR_SPEECH );
+	//allow for a number
+	int bufflen = strlen(text)+6;
+	char* newtext = ( char* ) malloc( bufflen );
+	snprintf( newtext, bufflen, text, value );
+	core->FreeString(text);
+	DisplayStringName(newtext, color, speaker);
+	free(newtext);
+}
+
 // String format is
 // <charname> - blah blah <someoneelse>
 void DisplayMessage::DisplayConstantStringAction(int stridx, unsigned int color, const Scriptable *attacker, const Scriptable *target) const
 {
 	unsigned int attacker_color;
-	const char *name1 = 0;
-	const char *name2 = 0;
+	char *name1 = 0;
+	char *name2 = 0;
 
 	if (stridx<0) return;
 
@@ -206,11 +228,29 @@ void DisplayMessage::DisplayConstantStringAction(int stridx, unsigned int color,
 	char* newstr = ( char* ) malloc( newlen );
 	snprintf( newstr, newlen, DisplayFormatAction, attacker_color, name1, color,
 		text, name2);
+	free( name1 );
+	free( name2 );
 	core->FreeString( text );
 	DisplayString( newstr );
 	free( newstr );
 }
 
+// display tokenized strings like ~Open lock check. Open lock skill %d vs. lock difficulty %d (%d DEX bonus).~
+void DisplayMessage::DisplayRollStringName(int stridx, unsigned int color, const Scriptable *speaker, ...) const
+{
+	ieDword feedback = 0;
+	core->GetDictionary()->Lookup("EnableRollFeedback", feedback);
+	if (feedback) {
+		char tmp[200];
+		va_list numbers;
+		va_start(numbers, speaker);
+		// fill it out
+		vsnprintf(tmp, sizeof(tmp), core->GetString(stridx), numbers);
+		displaymsg->DisplayStringName(tmp, color, speaker);
+		va_end(numbers);
+	}
+}
+
 void DisplayMessage::DisplayStringName(int stridx, unsigned int color, const Scriptable *speaker, ieDword flags) const
 {
 	if (stridx<0) return;
@@ -223,18 +263,20 @@ void DisplayMessage::DisplayStringName(int stridx, unsigned int color, const Scr
 void DisplayMessage::DisplayStringName(const char *text, unsigned int color, const Scriptable *speaker) const
 {
 	unsigned int speaker_color;
-	const char *name = 0;
+	char *name = 0;
 
 	if (!text) return;
 	speaker_color = GetSpeakerColor(name, speaker);
 
-	//FIXME: what happens if there is no name?
-	if (name) {
-		int newlen = (int)(strlen( DisplayFormatName ) + strlen( name ) +
-			+ strlen( text ) + 18);
-		char* newstr = ( char* ) malloc( newlen );
-		snprintf( newstr, newlen, DisplayFormatName, speaker_color, name, color, text );
-		DisplayString( newstr );
-		free( newstr );
+	if (strcmp(name, "")) {
+		int newlen = strlen(DisplayFormatName) + strlen(name) + strlen(text) + 18;
+		char* newstr = (char *) malloc(newlen);
+		snprintf(newstr, newlen, DisplayFormatName, speaker_color, name, color, text);
+		DisplayString(newstr);
+		free(newstr);
+	} else {
+		DisplayString(text, color, NULL);
 	}
+	free(name);
+}
 }
