@@ -534,15 +534,22 @@ int EffectQueue::AddEffect(Effect* fx, Scriptable* self, Actor* pretarget, const
 	ieDword spec = 0;
 	Actor *st = (self && (self->Type==ST_ACTOR)) ?(Actor *) self:NULL;
 	Effect* new_fx;
+	// HACK: 00p2229.baf in ar1006 does this silly thing, crashing later
+	if (!st && (self->Type==ST_CONTAINER) && (fx->Target == FX_TARGET_SELF)) {
+		fx->Target = FX_TARGET_PRESET;
+	}
 
 	if (self) {
 		fx->CasterID = self->GetGlobalID();
-	} else {
-		if (Owner) fx->CasterID = Owner->GetGlobalID();
+		fx->SetSourcePosition(self->Pos);
+	} else if (Owner) {
+		fx->CasterID = Owner->GetGlobalID();
+		fx->SetSourcePosition(Owner->Pos);
 	}
 
 	switch (fx->Target) {
 	case FX_TARGET_ORIGINAL:
+		assert(self != NULL);
 		fx->SetPosition(self->Pos);
 
 		flg = ApplyEffect( st, fx, 1 );
@@ -564,6 +571,7 @@ int EffectQueue::AddEffect(Effect* fx, Scriptable* self, Actor* pretarget, const
 		break;
 
 	case FX_TARGET_ALL_BUT_SELF:
+		assert(self != NULL);
 		new_fx = new Effect;
 		map=self->GetCurrentArea();
 		i= map->GetActorCount(true);
@@ -615,6 +623,7 @@ int EffectQueue::AddEffect(Effect* fx, Scriptable* self, Actor* pretarget, const
 		if( !pretarget || pretarget->InParty) {
 			goto all_party;
 		}
+		assert(self != NULL);
 		map = self->GetCurrentArea();
 		spec = pretarget->GetStat(IE_SPECIFIC);
 
@@ -671,6 +680,7 @@ all_party:
 		break;
 
 	case FX_TARGET_ALL:
+		assert(self != NULL);
 		new_fx = new Effect;
 		map = self->GetCurrentArea();
 		i = map->GetActorCount(true);
@@ -689,6 +699,7 @@ all_party:
 		break;
 
 	case FX_TARGET_ALL_BUT_PARTY:
+		assert(self != NULL);
 		new_fx = new Effect;
 		map = self->GetCurrentArea();
 		i = map->GetActorCount(false);
@@ -996,6 +1007,48 @@ static int check_type(Actor* actor, Effect* fx)
 	return 1;
 }
 
+// pure magic resistance
+static inline int check_magic_res(Actor *actor, Effect *fx, Actor *caster)
+{
+	//don't resist self
+	bool selective_mr = core->HasFeature(GF_SELECTIVE_MAGIC_RES);
+	if (fx->CasterID == actor->GetGlobalID()) {
+		if (selective_mr) {
+			return 0;
+		}
+	}
+
+	//magic immunity
+	ieDword val = actor->GetStat(IE_RESISTMAGIC);
+	bool resisted = false;
+
+	if (iwd2fx) {
+		// 3ed style check
+		// TODO: check if luck really affects it (i doubt it does)
+		int roll = actor->LuckyRoll(1, 20, 0);
+		ieDword check = fx->CasterLevel + roll;
+		int penetration = 0;
+		// +2/+4 level bonus from the (greater) spell penetration feat
+		if (caster && caster->HasFeat(FEAT_SPELL_PENETRATION)) {
+			penetration += 2 * caster->GetStat(IE_FEAT_SPELL_PENETRATION);
+		}
+		check += penetration;
+		resisted = (signed) check < (signed) val;
+		// ~Spell Resistance check (Spell resistance:) %d vs. (d20 + caster level + spell resistance mod)  = %d + %d + %d.~
+		displaymsg->DisplayRollStringName(39673, DMC_LIGHTGREY, actor, val, roll, fx->CasterLevel, penetration);
+	} else {
+		// 2.5 style check
+		resisted = (signed) fx->random_value < (signed) val;
+	}
+	if (resisted) {
+		// we take care of irresistible spells a few checks above, so selective mr has no impact here anymore
+		displaymsg->DisplayConstantStringName(STR_MAGIC_RESISTED, DMC_WHITE, actor);
+		Log(MESSAGE, "EffectQueue", "effect resisted: %s", (char*) Opcodes[fx->Opcode].Name);
+		return 1;
+	}
+	return 2;
+}
+
 //check resistances, saving throws
 static bool check_resistance(Actor* actor, Effect* fx)
 {
@@ -1030,52 +1083,18 @@ static bool check_resistance(Actor* actor, Effect* fx)
 	}
 */
 
-	//not resistable (no saves either?)
-	if(fx->Resistance != FX_CAN_RESIST_CAN_DISPEL) {
-		return false;
+	//not resistable (but check saves - for chromatic orb instakill)
+	if (fx->Resistance == FX_CAN_RESIST_CAN_DISPEL) {
+		int magic = check_magic_res(actor, fx, caster);
+		if (magic < 2) {
+			return magic;
+		}
 	}
 
 	if (pstflags && (actor->GetSafeStat(IE_STATE_ID) & (STATE_ANTIMAGIC) ) ) {
 		return false;
 	}
 
-	//don't resist self
-	bool selective_mr = core->HasFeature(GF_SELECTIVE_MAGIC_RES);
-	if (fx->CasterID == actor->GetGlobalID()) {
-		if (selective_mr) {
-			return false;
-		}
-	}
-
-	//magic immunity
-	ieDword val = actor->GetStat(IE_RESISTMAGIC);
-	bool resisted = false;
-
-	if (iwd2fx) {
-		// 3ed style check
-		// TODO: check if luck really affects it (i doubt it does)
-		int roll = actor->LuckyRoll(1, 20, 0);
-		ieDword check = fx->CasterLevel + roll;
-		int penetration = 0;
-		// +2/+4 level bonus from the (greater) spell penetration feat
-		if (caster && caster->HasFeat(FEAT_SPELL_PENETRATION)) {
-			penetration += 2 * caster->GetStat(IE_FEAT_SPELL_PENETRATION);
-		}
-		check += penetration;
-		resisted = (signed) check < (signed) val;
-		// ~Spell Resistance check (Spell resistance:) %d vs. (d20 + caster level + spell resistance mod)  = %d + %d + %d.~
-		displaymsg->DisplayRollStringName(39673, DMC_LIGHTGREY, actor, val, roll, fx->CasterLevel, penetration);
-	} else {
-		// 2.5 style check
-		resisted = (signed) fx->random_value < (signed) val;
-	}
-	if (resisted) {
-		// we take care of irresistible spells a few checks above, so selective mr has no impact here anymore
-		displaymsg->DisplayConstantStringName(STR_MAGIC_RESISTED, DMC_WHITE, actor);
-		Log(MESSAGE, "EffectQueue", "effect resisted: %s", (char*) Opcodes[fx->Opcode].Name);
-		return true;
-	}
-
 	//saving throws, bonus can be improved by school specific bonus
 	int bonus = fx->SavingThrowBonus + actor->fxqueue.BonusForParam2(fx_spell_resistance_ref, fx->PrimaryType);
 	if (caster) {
@@ -1134,10 +1153,7 @@ int EffectQueue::ApplyEffect(Actor* target, Effect* fx, ieDword first_apply, ieD
 
 	if (first_apply) {
 		fx->FirstApply = 1;
-		if( (fx->PosX==0xffffffff) && (fx->PosY==0xffffffff)) {
-			fx->PosX = target->Pos.x;
-			fx->PosY = target->Pos.y;
-		}
+		fx->SetPosition(target->Pos);
 
 		//gemrb specific, stat based chance
 		if ((fx->ProbabilityRangeMin == 100) && Owner && (Owner->Type==ST_ACTOR) ) {
