@@ -1156,19 +1156,25 @@ void Game::LoadCRTable()
 	}
 }
 
+// FIXME: figure out the real mechanism
 int Game::GetXPFromCR(int cr)
 {
 	if (!crtable) LoadCRTable();
 	if (crtable) {
 		int size = GetPartySize(true);
 		if (!size) return 0; // everyone just died anyway
+		// NOTE: this is an average of averages; if it turns out to be wrong,
+		// compute the party average directly
 		int level = GetPartyLevel(true) / size;
-		if (cr+1>=MAX_CRLEVEL) {
-			cr=MAX_CRLEVEL-2;
+		if (cr >= MAX_CRLEVEL) {
+			cr = MAX_CRLEVEL+1;
+		} else if (cr-2 < 0) {
+			cr = 2;
 		}
 		Log(MESSAGE, "Game", "Challenge Rating: %d, party level: %d", cr, level);
-		// it also has a column for cr 0.25 and 0.5
-		return crtable[level-1][cr+1];
+		// it also has a column for cr 0.25 and 0.5, so let's treat cr as a 1-based index
+		// but testing shows something else affects it further, so we divide by 2 to match
+		return crtable[level-1][cr-2]/2;
 	}
 	Log(ERROR, "Game", "Cannot find moncrate.2da!");
 	return 0;
@@ -1328,7 +1334,7 @@ void Game::AddGold(ieDword add)
 }
 
 //later this could be more complicated
-void Game::AdvanceTime(ieDword add)
+void Game::AdvanceTime(ieDword add, bool fatigue)
 {
 	ieDword h = GameTime/(300*AI_UPDATE_TIME);
 	GameTime+=add;
@@ -1339,6 +1345,14 @@ void Game::AdvanceTime(ieDword add)
 		core->GetGUIScriptEngine()->RunFunction("GUICommonWindows", "UpdateClock");
 	}
 	Ticks+=add*interval;
+	if (!fatigue) {
+		// update everyone in party, so they think no time has passed
+		// nobody else, including familiars, gets luck penalties from fatigue
+		for (unsigned int i=0; i<PCs.size(); i++) {
+			PCs[i]->IncreaseLastRested(add);
+		}
+	}
+
 	//change the tileset if needed
 	Map *map = GetCurrentArea();
 	if (map && map->ChangeMap(IsDay())) {
@@ -1745,7 +1759,7 @@ void Game::CastOnRest()
 						// we have the spell, so cast it on most injured
 						// NOTE: no distinction is made about the potency of spells
 						Actor *injuree = injurees[0];
-						tar->DirectlyCastSpell(injuree, special_spells[specialCount].resref, 0, 1, true, true, true);
+						tar->DirectlyCastSpell(injuree, special_spells[specialCount].resref, 0, 1, true);
 						if (injuree->GetStat(IE_HITPOINTS) == injuree->GetStat(IE_MAXHITPOINTS)) {
 							if (!injurees.empty()) {
 								injurees.erase(injurees.begin());
@@ -1851,19 +1865,25 @@ bool Game::IsDay()
 void Game::ChangeSong(bool always, bool force)
 {
 	int Song;
+	static int BattleSong = 0;
 
 	if (CombatCounter) {
 		//battlesong
 		Song = SONG_BATTLE;
+		BattleSong++;
 	} else {
 		//will select SONG_DAY or SONG_NIGHT
 		Song = (GameTime/AI_UPDATE_TIME)%7200/3600;
+		BattleSong = 0;
 	}
 	//area may override the song played (stick in battlemusic)
 	//always transition gracefully with ChangeSong
 	//force just means, we schedule the song for later, if currently
 	//is playing
-	area->PlayAreaSong( Song, always, force );
+	// make sure we only start one battle song at a time, since we're called once per party member
+	if (BattleSong < 2) {
+		area->PlayAreaSong( Song, always, force );
+	}
 }
 
 /* this method redraws weather. If update is false,
