@@ -44,6 +44,7 @@
 #include "Video.h"
 #include "WorldMap.h"
 #include "GUI/GameControl.h"
+#include "RNG/RNG_SFMT.h"
 #include "Scriptable/Container.h"
 #include "Scriptable/Door.h"
 #include "Scriptable/InfoPoint.h"
@@ -276,7 +277,7 @@ bool StoreHasItemCore(const ieResRef storename, const ieResRef itemname)
 	return ret;
 }
 
-bool StoreGetItemCore(CREItem &item, const ieResRef storename, const ieResRef itemname, unsigned int count)
+static bool StoreGetItemCore(CREItem &item, const ieResRef storename, const ieResRef itemname, unsigned int count)
 {
 	Store* store = gamedata->GetStore(storename);
 	if (!store) {
@@ -415,7 +416,7 @@ bool HasItemCore(Inventory *inventory, const ieResRef itemname, ieDword flags)
 }
 
 //finds and takes an item from a container in the given inventory
-bool GetItemContainer(CREItem &itemslot2, Inventory *inventory, const ieResRef itemname, int count)
+static bool GetItemContainer(CREItem &itemslot2, Inventory *inventory, const ieResRef itemname, int count)
 {
 	int i=inventory->GetSlotCount();
 	while (i--) {
@@ -787,7 +788,7 @@ static ScriptedAnimation *GetVVCEffect(const char *effect, int iterations)
 			Log(ERROR, "GameScript", "Failed to create effect.");
 			return NULL;
 		}
-		if (iterations) {
+		if (iterations > 1) {
 			vvc->SetDefaultDuration( vvc->GetSequenceDuration(AI_UPDATE_TIME * iterations));
 		} else {
 			vvc->PlayOnce();
@@ -830,7 +831,7 @@ void ChangeAnimationCore(Actor *src, const char *resref, bool effect)
 		// can't SetPosition while the old actor is taking the spot
 		tar->SetPosition(pos, 1);
 		if (effect) {
-			CreateVisualEffectCore(tar, tar->Pos,"smokepuffeffect",1);
+			CreateVisualEffectCore(tar, tar->Pos, "spsmpuff", 1);
 		}
 	}
 }
@@ -870,7 +871,7 @@ void EscapeAreaCore(Scriptable* Sender, const Point &p, const char* area, const
 	Sender->AddActionInFront( action );
 }
 
-void GetTalkPositionFromScriptable(Scriptable* scr, Point &position)
+static void GetTalkPositionFromScriptable(Scriptable* scr, Point &position)
 {
 	switch (scr->Type) {
 		case ST_AREA: case ST_GLOBAL:
@@ -922,16 +923,14 @@ static ieResRef PlayerDialogRes = "PLAYERx\0";
 void BeginDialog(Scriptable* Sender, Action* parameters, int Flags)
 {
 	Scriptable* tar, *scr;
-	int seeflag = GA_NO_DEAD;
 
 	if (InDebug&ID_VARIABLES) {
 		Log(MESSAGE, "GSUtils", "BeginDialog core");
 	}
+	tar = GetStoredActorFromObject(Sender, parameters->objects[1], GA_NO_DEAD);
 	if (Flags & BD_OWN) {
-		tar = GetStoredActorFromObject( Sender, parameters->objects[1], seeflag);
 		scr = tar;
 	} else {
-		tar = GetStoredActorFromObject( Sender, parameters->objects[1], seeflag);
 		scr = Sender;
 	}
 	if (!scr) {
@@ -940,6 +939,11 @@ void BeginDialog(Scriptable* Sender, Action* parameters, int Flags)
 		Sender->ReleaseCurrentAction();
 		return;
 	}
+	// do not allow disabled actors to start dialog
+	if (!(scr->GetInternalFlag() & IF_VISIBLE)) {
+		Sender->ReleaseCurrentAction();
+		return;
+	}
 
 	if (!tar || tar->Type!=ST_ACTOR) {
 		Log(ERROR, "GameScript", "Target for dialog couldn't be found (Sender: %s, Type: %d).",
@@ -1114,12 +1118,25 @@ void BeginDialog(Scriptable* Sender, Action* parameters, int Flags)
 
 	//don't clear target's actions, because a sequence like this will be broken:
 	//StartDialog([PC]); SetGlobal("Talked","LOCALS",1);
+	// Update orientation and potentially stance
+	// sarevok's resurrection cutscene shows a need for this (cut206a)
+	// however we do not want to affect lying actors (eg. Malla from tob)
 	if (scr!=tar) {
 		if (scr->Type==ST_ACTOR) {
-			((Actor *) scr)->SetOrientation(GetOrient( tar->Pos, scr->Pos), true);
+			// might not be equal to speaker anymore due to swapping
+			Actor *talker = (Actor *) scr;
+			talker->SetOrientation(GetOrient( tar->Pos, scr->Pos), true);
+			if (talker->InParty) {
+				talker->SetStance(IE_ANI_READY);
+			}
 		}
 		if (tar->Type==ST_ACTOR) {
-			((Actor *) tar)->SetOrientation(GetOrient( scr->Pos, tar->Pos), true);
+			// might not be equal to target anymore due to swapping
+			Actor *talkee = (Actor *) tar;
+			talkee->SetOrientation(GetOrient( scr->Pos, tar->Pos), true);
+			if (talkee->InParty) {
+				talkee->SetStance(IE_ANI_READY);
+			}
 		}
 	}
 
@@ -1173,6 +1190,7 @@ void MoveBetweenAreasCore(Actor* actor, const char *area, const Point &position,
 	Map* map1 = actor->GetCurrentArea();
 	Map* map2;
 	Game* game = core->GetGame();
+	bool newSong = false;
 	if (area[0] && (!map1 || stricmp(area, map1->GetScriptName()))) { //do we need to switch area?
 		//we have to change the pathfinder
 		//to the target area if adjust==true
@@ -1181,6 +1199,7 @@ void MoveBetweenAreasCore(Actor* actor, const char *area, const Point &position,
 			map1->RemoveActor( actor );
 		}
 		map2->AddActor( actor, true );
+		newSong = true;
 
 		// update the worldmap if needed
 		if (actor->InParty) {
@@ -1203,7 +1222,9 @@ void MoveBetweenAreasCore(Actor* actor, const char *area, const Point &position,
 	if (actor->InParty) {
 		GameControl *gc=core->GetGameControl();
 		gc->SetScreenFlags(SF_CENTERONACTOR,BM_OR);
-		game->ChangeSong(false, true);
+		if (newSong) {
+			game->ChangeSong(false, true);
+		}
 	}
 }
 
@@ -2301,7 +2322,7 @@ int GetGroup(Actor *actor)
 	if (actor->GetStat(IE_EA) <= EA_GOODCUTOFF) {
 		type = 1; //PC
 	}
-	if (actor->GetStat(IE_EA) >= EA_EVILCUTOFF) {
+	else if (actor->GetStat(IE_EA) >= EA_EVILCUTOFF) {
 		type = 0;
 	}
 	return type;
@@ -2325,7 +2346,6 @@ Actor *GetNearestEnemyOf(Map *map, Actor *origin, int whoseeswho)
 		ac=map->GetActor(i,true);
 		if (ac == origin) continue;
 
-		int distance = Distance(ac, origin);
 		if (whoseeswho&ENEMY_SEES_ORIGIN) {
 			if (!CanSee(ac, origin, true, GA_NO_DEAD|GA_NO_UNSCHEDULED)) {
 				continue;
@@ -2337,6 +2357,7 @@ Actor *GetNearestEnemyOf(Map *map, Actor *origin, int whoseeswho)
 			}
 		}
 
+		int distance = Distance(ac, origin);
 		if (type) { //origin is PC
 			if (ac->GetStat(IE_EA) >= EA_EVILCUTOFF) {
 				tgts->AddTarget(ac, distance, GA_NO_DEAD|GA_NO_UNSCHEDULED);
@@ -2363,7 +2384,6 @@ Actor *GetNearestOf(Map *map, Actor *origin, int whoseeswho)
 		ac=map->GetActor(i,true);
 		if (ac == origin) continue;
 
-		int distance = Distance(ac, origin);
 		if (whoseeswho&ENEMY_SEES_ORIGIN) {
 			if (!CanSee(ac, origin, true, GA_NO_DEAD|GA_NO_UNSCHEDULED)) {
 				continue;
@@ -2375,6 +2395,7 @@ Actor *GetNearestOf(Map *map, Actor *origin, int whoseeswho)
 			}
 		}
 
+		int distance = Distance(ac, origin);
 		tgts->AddTarget(ac, distance, GA_NO_DEAD|GA_NO_UNSCHEDULED);
 	}
 	ac = (Actor *) tgts->GetTarget(0, ST_ACTOR);
@@ -2411,13 +2432,13 @@ unsigned int GetSpellDistance(const ieResRef spellres, Scriptable *Sender)
 		return 0;
 	}
 	dist = spl->GetCastingDistance(Sender);
+	gamedata->FreeSpell(spl, spellres, false);
+
 	//make possible special return values (like 0xffffffff means the spell doesn't need distance)
 	//this is used with special targeting mode (3)
 	if (dist>0xff000000) {
 		return dist;
 	}
-
-	gamedata->FreeSpell(spl, spellres, false);
 	return dist*9; //FIXME: empirical constant to convert from points to (feet)
 }
 
@@ -2433,13 +2454,13 @@ unsigned int GetItemDistance(const ieResRef itemres, int header)
 		return 0;
 	}
 	dist=itm->GetCastingDistance(header);
+	gamedata->FreeItem(itm, itemres, false);
+
 	//make possible special return values (like 0xffffffff means the item doesn't need distance)
 	//this is used with special targeting mode (3)
 	if (dist>0xff000000) {
 		return dist;
 	}
-
-	gamedata->FreeItem(itm, itemres, false);
 	return dist*15;
 }
 
@@ -2479,7 +2500,7 @@ void SetupWishCore(Scriptable *Sender, int column, int picks)
 		}
 	} else {
 		for(i=0;i<picks;i++) {
-			selects[i]=rand()%count;
+			selects[i]=RAND(0, count-1);
 retry:
 			for(j=0;j<i;j++) {
 				if(selects[i]==selects[j]) {
@@ -2569,43 +2590,25 @@ Gem_Polygon *GetPolygon2DA(ieDword index)
 	return polygons[index];
 }
 
-inline static bool InterruptSpellcasting(Scriptable* Sender) {
+static bool InterruptSpellcasting(Scriptable* Sender) {
 	if (Sender->Type != ST_ACTOR) return false;
 	Actor *caster = (Actor *) Sender;
 
 	// ouch, we got hit
 	if (Sender->InterruptCasting) {
-		int roll = 0;
-
-		// iwd2 does an extra concentration check first:
-		// d20 + Concentration Skill Level + Constitution bonus (+4 Combat casting feat) >= 15 + spell level
-		if (core->HasFeature(GF_3ED_RULES)) {
-			roll = core->Roll(1, 20, 0); // TODO: check if the original does a lucky roll
-			roll += caster->GetStat(IE_CONCENTRATION);
-			roll += caster->GetAbilityBonus(IE_CON);
-			if (caster->HasFeat(FEAT_COMBAT_CASTING)) {
-				roll += 4;
-			}
-			Spell* spl = gamedata->GetSpell(Sender->SpellResRef, true);
-			if (!spl) return false;
-			roll -= spl->SpellLevel;
-			gamedata->FreeSpell(spl, Sender->SpellResRef, false);
-		}
-		if (roll < 15) {
-			if (caster->InParty) {
-				displaymsg->DisplayConstantString(STR_SPELLDISRUPT, DMC_WHITE, Sender);
-			} else {
-				displaymsg->DisplayConstantStringName(STR_SPELL_FAILED, DMC_WHITE, Sender);
-			}
-			DisplayStringCore(Sender, VB_SPELL_DISRUPTED, DS_CONSOLE|DS_CONST );
-			return true;
+		if (caster->InParty) {
+			displaymsg->DisplayConstantString(STR_SPELLDISRUPT, DMC_WHITE, Sender);
+		} else {
+			displaymsg->DisplayConstantStringName(STR_SPELL_FAILED, DMC_WHITE, Sender);
 		}
+		DisplayStringCore(Sender, VB_SPELL_DISRUPTED, DS_CONSOLE|DS_CONST );
+		return true;
 	}
 
 	// abort casting on invisible or dead targets
 	// not all spells should be interrupted on death - some for chunking, some for raising the dead
-	if (Sender->LastTarget) {
-		Actor *target = core->GetGame()->GetActorByGlobalID(Sender->LastTarget);
+	if (Sender->LastSpellTarget) {
+		Actor *target = core->GetGame()->GetActorByGlobalID(Sender->LastSpellTarget);
 		if (target) {
 			ieDword state = target->GetStat(IE_STATE_ID);
 			if (state & STATE_DEAD) {
@@ -2613,15 +2616,15 @@ inline static bool InterruptSpellcasting(Scriptable* Sender) {
 					Spell* spl = gamedata->GetSpell(Sender->SpellResRef, true);
 					if (!spl) return false;
 					SPLExtHeader *seh = spl->GetExtHeader(0); // potentially wrong, but none of the existing spells is problematic
-					if (seh && seh->Target != TARGET_DEAD) {
-						gamedata->FreeSpell(spl, Sender->SpellResRef, false);
+					bool invalidTarget = seh && seh->Target != TARGET_DEAD;
+					gamedata->FreeSpell(spl, Sender->SpellResRef, false);
+					if (invalidTarget) {
 						if (caster->InParty) {
 							core->Autopause(AP_NOTARGET, caster);
 						}
 						caster->SetStance(IE_ANI_READY);
 						return true;
 					}
-					gamedata->FreeSpell(spl, Sender->SpellResRef, false);
 				}
 			}
 		}
@@ -2728,7 +2731,7 @@ void SpellCore(Scriptable *Sender, Action *parameters, int flags)
 		return;
 	}
 
-	if (Sender->LastTarget) {
+	if (Sender->LastSpellTarget) {
 		//if target was set, fire spell
 		Sender->CastSpellEnd(level, flags&SC_INSTANT);
 	} else if(!Sender->LastTargetPos.isempty()) {
