@@ -30,6 +30,7 @@
 #include "Interface.h"
 #include "PluginMgr.h"
 #include "TableMgr.h"
+#include "RNG/RNG_SFMT.h"
 #include "System/StringBuffer.h"
 
 namespace GemRB {
@@ -190,6 +191,8 @@ static const TriggerLink triggernames[] = {
 	{"hppercent", GameScript::HPPercent, 0},
 	{"hppercentgt", GameScript::HPPercentGT, 0},
 	{"hppercentlt", GameScript::HPPercentLT, 0},
+	{"ifvalidforpartydialog", GameScript::IsValidForPartyDialog, 0},
+	{"ifvalidforpartydialogue", GameScript::IsValidForPartyDialog, 0},
 	{"inactivearea", GameScript::InActiveArea, 0},
 	{"incutscenemode", GameScript::InCutSceneMode, 0},
 	{"inline", GameScript::InLine, 0},
@@ -1299,7 +1302,7 @@ static void CleanupIEScript()
 	ObjectIDSTableNames = NULL;
 }
 
-void printFunction(StringBuffer& buffer, Holder<SymbolMgr> table, int index)
+static void printFunction(StringBuffer& buffer, Holder<SymbolMgr> table, int index)
 {
 	const char *str = table->GetStringIndex(index);
 	int value = table->GetValueIndex(index);
@@ -1312,7 +1315,7 @@ void printFunction(StringBuffer& buffer, Holder<SymbolMgr> table, int index)
 	}
 }
 
-void LoadActionFlags(const char *tableName, int flag, bool critical)
+static void LoadActionFlags(const char *tableName, int flag, bool critical)
 {
 	int i, j;
 
@@ -1952,7 +1955,7 @@ bool GameScript::Update(bool *continuing, bool *done)
 	bool continueExecution = false;
 	if (continuing) continueExecution = *continuing;
 
-	RandomNumValue=rand();
+	RandomNumValue=RNG_SFMT::getInstance()->rand();
 	for (size_t a = 0; a < script->responseBlocks.size(); a++) {
 		ResponseBlock* rB = script->responseBlocks[a];
 		if (rB->condition->Evaluate(MySelf)) {
@@ -2258,7 +2261,7 @@ int ResponseSet::Execute(Scriptable* Sender)
 		maxWeight += responses[i]->weight;
 	}
 	if (maxWeight) {
-		randWeight = rand() % maxWeight;
+		randWeight = RAND(0, maxWeight-1);
 	}
 	else {
 		randWeight = 0;
@@ -2308,7 +2311,7 @@ int Response::Execute(Scriptable* Sender)
 	return ret;
 }
 
-void PrintAction(StringBuffer& buffer, int actionID)
+static void PrintAction(StringBuffer& buffer, int actionID)
 {
 	buffer.appendFormatted("Action: %d %s\n", actionID, actionsTable->GetValue(actionID));
 }
@@ -2559,7 +2562,7 @@ void Action::dump(StringBuffer& buffer) const
 
 	AssertCanary(__FUNCTION__);
 	buffer.appendFormatted("Int0: %d, Int1: %d, Int2: %d\n",int0Parameter, int1Parameter, int2Parameter);
-	buffer.appendFormatted("String0: %s, String1: %s\n", string0Parameter?string0Parameter:"<NULL>", string1Parameter?string1Parameter:"<NULL>");
+	buffer.appendFormatted("String0: %s, String1: %s\n", string0Parameter[0]?string0Parameter:"<NULL>", string1Parameter[0]?string1Parameter:"<NULL>");
 	for (i=0;i<3;i++) {
 		if (objects[i]) {
 			buffer.appendFormatted( "%d. ",i+1);
