@@ -31,6 +31,13 @@
 #include <cstdio>
 #include <vector>
 
+// absent from msvc6
+#ifdef _MSC_VER
+#ifndef __FUNCTION
+#define __FUNCTION__ "no message"
+#endif
+#endif
+
 namespace GemRB {
 
 class Action;
@@ -536,6 +543,7 @@ private: //Internal Functions
 	ResponseSet* ReadResponseSet(DataStream* stream);
 	Response* ReadResponse(DataStream* stream);
 	Trigger* ReadTrigger(DataStream* stream);
+	static int InParty(Scriptable* Sender, Trigger* parameters, bool allowdead);
 private: //Internal variables
 	Scriptable* const MySelf;
 	ieResRef Name;
