@@ -23,6 +23,8 @@
 #include "Sprite2D.h"
 #include "System/DataStream.h"
 
+namespace GemRB {
+
 class GEM_EXPORT ImageWriter : public Plugin {
 public:
 	ImageWriter(void);
@@ -32,4 +34,6 @@ public:
 	virtual void PutImage(DataStream *output, Sprite2D *sprite) = 0;
 };
 
+}
+
 #endif
