@@ -25,6 +25,8 @@
 
 #include "Plugin.h"
 
+namespace GemRB {
+
 class GEM_EXPORT IndexedArchive : public Plugin {
 public:
 	IndexedArchive(void);
@@ -33,4 +35,6 @@ public:
 	virtual DataStream* GetStream(unsigned long Resource, unsigned long Type) = 0;
 };
 
+}
+
 #endif
