@@ -333,8 +333,9 @@ public:
 	unsigned int FindStealableItem();
 	/** checks if any equipped item provides critical hit aversion */
 	bool ProvidesCriticalAversion();
-	/** tries to merge the passed item with the on in the passed slot */
+	/** tries to merge the passed item with the one in the passed slot */
 	int MergeItems(int slot, CREItem *item);
+	bool FistsEquipped() const;
 	//setting important constants
 	static void Init();
 	static void SetArmorSlot(int arg);
