@@ -32,6 +32,8 @@
 #include "Plugin.h"
 #include "System/DataStream.h"
 
+namespace GemRB {
+
 /**
  * @class ItemMgr
  * Abstract loader for Item objects
@@ -45,4 +47,6 @@ public:
 	virtual Item* GetItem(Item *s) = 0;
 };
 
+}
+
 #endif
