@@ -33,6 +33,7 @@
 #include "Sprite2D.h"
 #include "VEFObject.h"
 #include "Video.h"
+#include "RNG/RNG_SFMT.h"
 #include "Scriptable/Actor.h"
 
 #include <cmath>
@@ -140,7 +141,7 @@ void Projectile::CreateAnimations(Animation **anims, const ieResRef bamres, int
 	}
 
 	if((ExtFlags&PEF_CYCLE) && !Seq) {
-		Seq=rand()%Max;
+		Seq=RAND(0, Max-1);
 	}
 
 	//this hack is needed because bioware .pro files are sometimes
@@ -573,19 +574,9 @@ void Projectile::Payload()
 			target = area->GetActorByGlobalID(Caster);			
 		}
 	}
-	Actor *source = area->GetActorByGlobalID(Caster);
-	InfoPoint *source2 = area->GetInfoPointByGlobalID(Caster);
-	Container *source3 = area->GetContainerByGlobalID(Caster);
-	Door *source4 = area->GetDoorByGlobalID(Caster);
-	if (source) {
-		Owner = source;
-	} else if (source2) {
-		Owner = (Scriptable *) source2;
-	} else if (source3) {
-		Owner = (Scriptable *) source3;
-	} else if (source4) {
-		Owner = (Scriptable *) source4;
-	} else {
+	
+	Owner = area->GetScriptableByGlobalID(Caster);
+	if (!Owner) {
 		Log(WARNING, "Projectile", "Payload: Caster not found, using target!");
 		Owner = target;
 	}
@@ -1099,6 +1090,7 @@ void Projectile::LineTarget()
 				}
 
 				eff->AddAllEffects(target, target->Pos);
+				delete eff;
 			}
 		}
 		iter = iter->Next;
@@ -1478,7 +1470,7 @@ void Projectile::DrawExplosion(const Region &screen)
 			if (children[i])
 				continue;
 			if(apflags&APF_BOTH) {
-				if(rand()&1) {
+				if(RAND(0,1)) {
 					tmp = Extension->Secondary;
 				} else {
 					tmp = Extension->Spread;
@@ -1522,12 +1514,12 @@ void Projectile::DrawExplosion(const Region &screen)
 				//a bit of difference in case crowding is needed
 				//make this a separate flag if speed difference
 				//is not always wanted
-				pro->Speed-=rand()&7;
+				pro->Speed-=RAND(0,7);
 
 				delay = Extension->Delay*extension_explosioncount;
 				if(apflags&APF_BOTH) {
 					if (delay) {
-						delay = rand()%delay;
+						delay = RAND(0, delay-1);
 					}
 				}
 				//this needs to be commented out for ToB horrid wilting
