@@ -23,6 +23,10 @@
 
 #include "Plugin.h"
 
+namespace GemRB {
+
+class Point;
+
 class GEM_EXPORT ScriptEngine : public Plugin {
 public:
 	ScriptEngine(void);
@@ -32,9 +36,12 @@ public:
 	/** Load Script */
 	virtual bool LoadScript(const char* filename) = 0;
 	/** Run Function */
-	virtual bool RunFunction(const char *ModuleName, const char* FunctionName, bool error=true, int intparam=-1) = 0;
+	virtual bool RunFunction(const char *ModuleName, const char* FunctionName, bool report_error=true, int intparam=-1) = 0;
+	virtual bool RunFunction(const char* Modulename, const char* FunctionName, bool report_error, Point) = 0;
 	/** Exec a single String */
 	virtual void ExecString(const char* string) = 0;
 };
 
+}
+
 #endif
