@@ -170,6 +170,7 @@ namespace GemRB {
 #define UI_MISS      2       //ranged miss (projectile has no effects)
 #define UI_CRITICAL  4       //a critical hit happened
 #define UI_FAKE      8       //deplete the item but don't actually apply its effects
+#define UI_NOAURA    16      //ignore spellcasting aura checks
 
 //used to mask off current profs
 #define PROFS_MASK  0x07
@@ -403,11 +404,12 @@ private:
 	void RefreshPCStats();
 	void RefreshHP();
 	bool ShouldHibernate();
-	void ApplyClassClab(int cls, bool remove);
 	bool ShouldDrawCircle() const;
 	bool HasBodyHeat() const;
 	void SetupFistData();
 	void UpdateFatigue();
+	int GetSneakAttackDamage(Actor *target, WeaponInfo &wi, int &multiplier, bool weaponImmunity);
+	int GetBackstabDamage(Actor *target, WeaponInfo &wi, int multiplier, int damage) const;
 public:
 	Actor(void);
 	~Actor(void);
@@ -549,8 +551,8 @@ public:
 	void DialogInterrupt();
 	/* called when actor was hit */
 	void GetHit(int damage=0, int spellLevel=0);
-	/* checks whether concentration cancels damage taken disrupting casting */
-	bool CheckCastingInterrupt(int damage, int spellLevel);
+	/* checks whether taking damage should disrupt spellcasting */
+	bool CheckSpellDisruption(int damage, int spellLevel);
 	/* called when actor starts to cast a spell*/
 	bool HandleCastingStance(const ieResRef SpellResRef, bool deplete, bool instant);
 	/* check if the actor should be just knocked out by a lethal hit */
@@ -581,7 +583,7 @@ public:
 	/* sets some of the internal flags */
 	void SetRunFlags(ieDword flags);
 	/* applies the kit abilities, returns false if kit is not applicable */
-	bool ApplyKit(bool remove);
+	bool ApplyKit(bool remove, ieDword baseclass=0);
 	/* applies the class abilities*/
 	void ApplyClab(const char *clab, ieDword max, bool remove);
 	/* calls InitQuickSlot in PCStatStruct */
@@ -603,7 +605,7 @@ public:
 	/* debug function */
 	void GetNextStance();
 	/* learns the given spell, possibly receive XP */
-	int LearnSpell(const ieResRef resref, ieDword flags);
+	int LearnSpell(const ieResRef resref, ieDword flags, int bookmask=-1, int level=-1);
 	/* returns the ranged weapon header associated with the currently equipped projectile */
 	ITMExtHeader *GetRangedWeapon(WeaponInfo &wi) const;
 	/* Returns current weapon range and extended header
@@ -756,10 +758,10 @@ public:
 	int GetMaxEncumbrance() const;
 	int GetAbilityBonus(unsigned int ability, int value = -1) const;
 	int GetSkillStat(unsigned int skill) const;
-	int GetSkill(unsigned int skill) const;
+	int GetSkill(unsigned int skill, bool ids=false) const;
 	int GetFeat(unsigned int feat) const;
 	void SetFeat(unsigned int feat, int mode);
-	void SetFeatValue(unsigned int feat, int value);
+	void SetFeatValue(unsigned int feat, int value, bool init = true);
 	void SetUsedWeapon(const char *AnimationType, ieWord *MeleeAnimation,
 		int WeaponType=-1);
 	void SetUsedShield(const char *AnimationType, int WeaponType=-1);
@@ -881,6 +883,9 @@ public:
 	void SetDisarmingTrap(ieDword trapId) { disarmTrap = trapId; }
 	ieDword GetDisarmingTrap() const { return disarmTrap; }
 	void ReleaseCurrentAction();
+	bool ConcentrationCheck() const;
+	void ApplyEffectCopy(Effect *oldfx, EffectRef &newref, Scriptable *Owner, ieDword param1, ieDword param2);
+	void IncreaseLastRested(int inc) { TicksLastRested += inc; }
 };
 }
 
