@@ -22,24 +22,19 @@
 #include "strrefs.h"
 #include "win32def.h"
 
-#include "Audio.h"
 #include "DisplayMessage.h"
 #include "Game.h"
 #include "GameData.h"
-#include "Interface.h"
 #include "Item.h"
-#include "Map.h"
-#include "Projectile.h"
-#include "Spell.h"
 #include "Sprite2D.h"
 #include "SpriteCover.h"
 #include "TileMap.h"
 #include "Video.h"
 #include "GameScript/GSUtils.h"
 #include "GUI/GameControl.h"
+#include "System/StringBuffer.h"
 
-#include <cassert>
-#include <cmath>
+namespace GemRB {
 
 #define YESNO(x) ( (x)?"Yes":"No")
 
@@ -169,8 +164,8 @@ void Container::DestroyContainer()
 CREItem *Container::RemoveItem(unsigned int idx, unsigned int count)
 {
 	CREItem *ret = inventory.RemoveItem(idx, count);
-	//we just took the 3. or less item, groundpile changed
-	if ((Type == IE_CONTAINER_PILE) && (inventory.GetSlotCount()<3)) {
+	//if we just took one of the first few items, groundpile changed
+	if ((Type == IE_CONTAINER_PILE) && (idx<MAX_GROUND_ICON_DRAWN)) {
 		RefreshGroundIcons();
 	}
 	return ret;
@@ -182,7 +177,7 @@ int Container::AddItem(CREItem *item)
 {
 	inventory.AddItem(item);
 	//we just added a 3. or less item, groundpile changed
-	if ((Type == IE_CONTAINER_PILE) && (inventory.GetSlotCount()<4)) {
+	if ((Type == IE_CONTAINER_PILE) && (inventory.GetSlotCount()<=MAX_GROUND_ICON_DRAWN)) {
 		RefreshGroundIcons();
 	}
 	return 2;
@@ -226,23 +221,37 @@ int Container::IsOpen() const
 
 void Container::TryPickLock(Actor *actor)
 {
-	core->PlaySound(DS_PICKLOCK);
 	if (LockDifficulty == 100) {
 		if (OpenFail != (ieDword)-1) {
-			displaymsg->DisplayStringName(OpenFail, 0xbcefbc, actor, IE_STR_SOUND|IE_STR_SPEECH);
+			displaymsg->DisplayStringName(OpenFail, DMC_BG2XPGREEN, actor, IE_STR_SOUND|IE_STR_SPEECH);
 		} else {
-			displaymsg->DisplayConstantStringName(STR_CONT_NOPICK, 0xbcefbc, actor);
+			displaymsg->DisplayConstantStringName(STR_CONT_NOPICK, DMC_BG2XPGREEN, actor);
 		}
 		return;
 	}
-	if (actor->GetStat(IE_LOCKPICKING)<LockDifficulty) {
-		displaymsg->DisplayConstantStringName(STR_LOCKPICK_FAILED, 0xbcefbc, actor);
+	int stat = actor->GetStat(IE_LOCKPICKING);
+	if (core->HasFeature(GF_3ED_RULES)) {
+		int skill = actor->GetSkill(IE_LOCKPICKING);
+		if (skill == 0) { // a trained skill, make sure we fail
+			stat = 0;
+		} else {
+			stat *= 7; // convert to percent (magic 7 is from RE)
+			int dexmod = actor->GetAbilityBonus(IE_DEX);
+			stat += dexmod; // the original didn't use it, so let's not multiply it
+			displaymsg->DisplayRollStringName(39301, DMC_LIGHTGREY, actor, stat-dexmod, LockDifficulty, dexmod);
+		}
+	}
+	if (stat < LockDifficulty) {
+		displaymsg->DisplayConstantStringName(STR_LOCKPICK_FAILED, DMC_BG2XPGREEN, actor);
 		AddTrigger(TriggerEntry(trigger_picklockfailed, actor->GetGlobalID()));
+		core->PlaySound(DS_PICKFAIL); //AMB_D21
 		return;
 	}
 	SetContainerLocked(false);
-	displaymsg->DisplayConstantStringName(STR_LOCKPICK_DONE, 0xd7d7be, actor);
+	core->GetGameControl()->ResetTargetMode();
+	displaymsg->DisplayConstantStringName(STR_LOCKPICK_DONE, DMC_LIGHTGREY, actor);
 	AddTrigger(TriggerEntry(trigger_unlocked, actor->GetGlobalID()));
+	core->PlaySound(DS_PICKLOCK); //AMB_D21D
 	ImmediateEvent();
 	int xp = actor->CalculateExperience(XP_LOCKPICK, actor->GetXPLevel(1));
 	Game *game = core->GetGame();
@@ -252,39 +261,55 @@ void Container::TryPickLock(Actor *actor)
 void Container::TryBashLock(Actor *actor)
 {
 	//Get the strength bonus agains lock difficulty
-	int str = actor->GetStat(IE_STR);
-	int strEx = actor->GetStat(IE_STREXTRA);
-	unsigned int bonus = core->GetStrengthBonus(2, str, strEx); //BEND_BARS_LIFT_GATES
+	int bonus;
+
+	if (core->HasFeature(GF_3ED_RULES)) {
+		bonus = actor->GetAbilityBonus(IE_STR);
+	} else {
+		int str = actor->GetStat(IE_STR);
+		int strEx = actor->GetStat(IE_STREXTRA);
+		bonus = core->GetStrengthBonus(2, str, strEx); //BEND_BARS_LIFT_GATES
+	}
 	unsigned int roll = actor->LuckyRoll(1, 10, bonus, 0);
 
+	if (core->HasFeature(GF_3ED_RULES)) {
+		// ~Bash door check. Roll %d + %d Str mod > %d door DC.~
+		// there is no separate string for non-doors
+		displaymsg->DisplayRollStringName(20460, DMC_LIGHTGREY, actor, roll, bonus, LockDifficulty);
+	}
+
+	actor->FaceTarget(this);
 	if(roll < LockDifficulty || LockDifficulty == 100) {
-		displaymsg->DisplayConstantStringName(STR_CONTBASH_FAIL, 0xbcefbc, actor);
+		displaymsg->DisplayConstantStringName(STR_CONTBASH_FAIL, DMC_BG2XPGREEN, actor);
 		return;
 	}
 
-	displaymsg->DisplayConstantStringName(STR_CONTBASH_DONE, 0xd7d7be, actor);
+	displaymsg->DisplayConstantStringName(STR_CONTBASH_DONE, DMC_LIGHTGREY, actor);
 	SetContainerLocked(false);
+	core->GetGameControl()->ResetTargetMode();
 	//Is this really useful ?
 	AddTrigger(TriggerEntry(trigger_unlocked, actor->GetGlobalID()));
 	ImmediateEvent();
 }
 
-void Container::DebugDump() const
+void Container::dump() const
 {
-	print( "Debugdump of Container %s\n", GetScriptName() );
-	print( "Container Global ID: %d\n", GetGlobalID());
-	print( "Position: %d.%d\n", Pos.x, Pos.y);
-	print( "Type: %d, Locked: %s, LockDifficulty: %d\n", Type, YESNO(Flags&CONT_LOCKED), LockDifficulty );
-	print( "Flags: %d, Trapped: %s, Detected: %d\n", Flags, YESNO(Trapped), TrapDetected );
-	print( "Trap detection: %d%%, Trap removal: %d%%\n", TrapDetectionDiff,
+	StringBuffer buffer;
+	buffer.appendFormatted( "Debugdump of Container %s\n", GetScriptName() );
+	buffer.appendFormatted( "Container Global ID: %d\n", GetGlobalID());
+	buffer.appendFormatted( "Position: %d.%d\n", Pos.x, Pos.y);
+	buffer.appendFormatted( "Type: %d, Locked: %s, LockDifficulty: %d\n", Type, YESNO(Flags&CONT_LOCKED), LockDifficulty );
+	buffer.appendFormatted( "Flags: %d, Trapped: %s, Detected: %d\n", Flags, YESNO(Trapped), TrapDetected );
+	buffer.appendFormatted( "Trap detection: %d%%, Trap removal: %d%%\n", TrapDetectionDiff,
 		TrapRemovalDiff );
 	const char *name = "NONE";
 	if (Scripts[0]) {
 		name = Scripts[0]->GetName();
 	}
-	print( "Script: %s, Key: %s\n", name, KeyResRef );
+	buffer.appendFormatted( "Script: %s, Key: %s\n", name, KeyResRef );
 	// FIXME: const_cast
-	const_cast<Inventory&>(inventory).dump();
+	inventory.dump(buffer);
+	Log(DEBUG, "Container", buffer);
 }
 
 bool Container::TryUnlock(Actor *actor) {
@@ -293,3 +318,5 @@ bool Container::TryUnlock(Actor *actor) {
 	return Highlightable::TryUnlock(actor, false);
 }
 
+
+}
