@@ -34,12 +34,11 @@
 #include "GameScript/GSUtils.h"
 #include "GameScript/Matching.h" // MatchActor
 #include "GUI/GameControl.h"
+#include "RNG/RNG_SFMT.h"
 #include "Scriptable/InfoPoint.h"
 
 namespace GemRB {
 
-#define YESNO(x) ( (x)?"Yes":"No")
-
 // we start this at a non-zero value to make debugging easier
 static ieDword globalActorCounter = 10000;
 static bool startActive = false;
@@ -110,6 +109,7 @@ Scriptable::Scriptable(ScriptableType type)
 	Pos.x = 0;
 	Pos.y = 0;
 
+	LastTarget = 0;
 	LastSpellOnMe = 0xffffffff;
 	ResetCastingState(NULL);
 	InterruptCasting = false;
@@ -131,16 +131,12 @@ Scriptable::~Scriptable(void)
 	}
 	ClearActions();
 	for (int i = 0; i < MAX_SCRIPTS; i++) {
-		if (Scripts[i]) {
-			delete( Scripts[i] );
-		}
+		delete Scripts[i];
 	}
 	if (overHeadText) {
 		core->FreeString( overHeadText );
 	}
-	if (locals) {
-		delete( locals );
-	}
+	delete locals;
 }
 
 void Scriptable::SetScriptName(const char* text)
@@ -159,10 +155,10 @@ const char* Scriptable::GetScriptName(void) const
 }
 
 void Scriptable::SetDialog(const char *resref) {
-		if (gamedata->Exists(resref, IE_DLG_CLASS_ID) ) {
-			strnuprcpy(Dialog, resref, 8);
-		}
+	if (gamedata->Exists(resref, IE_DLG_CLASS_ID) ) {
+		strnuprcpy(Dialog, resref, 8);
 	}
+}
 
 Map* Scriptable::GetCurrentArea() const
 {
@@ -187,9 +183,7 @@ void Scriptable::SetScript(const ieResRef aScript, int idx, bool ai)
 	if (idx >= MAX_SCRIPTS) {
 		error("Scriptable", "Invalid script index!\n");
 	}
-	if (Scripts[idx]) {
-		delete Scripts[idx];
-	}
+	delete Scripts[idx];
 	Scripts[idx] = NULL;
 	// NONE is an 'invalid' script name, never used seriously
 	// This hack is to prevent flooding of the console
@@ -205,9 +199,7 @@ void Scriptable::SetScript(int index, GameScript* script)
 		Log(ERROR, "Scriptable", "Invalid script index!");
 		return;
 	}
-	if (Scripts[index] ) {
-		delete Scripts[index];
-	}
+	delete Scripts[index];
 	Scripts[index] = script;
 }
 
@@ -303,16 +295,11 @@ void Scriptable::Update()
 	AdjustedTicks++;
 	AuraTicks++;
 
-	Actor *act = NULL;
-	if (Type == ST_ACTOR) {
-		act = (Actor *) this;
-	}
-
 	if (UnselectableTimer) {
 		UnselectableTimer--;
 		if (!UnselectableTimer) {
-			if (act) {
-				act->SetCircleSize();
+			if (Type == ST_ACTOR) {
+				((Actor *) this)->SetCircleSize();
 			}
 		}
 	}
@@ -393,13 +380,18 @@ void Scriptable::ExecuteScript(int scriptCount)
 
 	bool changed = false;
 
-	// if party AI is disabled, don't run non-override scripts
-	if (Type == ST_ACTOR && ((Actor *) this)->InParty && (core->GetGame()->ControlStatus & CS_PARTY_AI))
-		scriptCount = 1;
-	// TODO: hardcoded action hacks
+	Actor *act = NULL;
 	if (Type == ST_ACTOR) {
+		act = (Actor *) this;
+	}
+
+	if (act) {
+		// if party AI is disabled, don't run non-override scripts
+		if (act->InParty && (core->GetGame()->ControlStatus & CS_PARTY_AI))
+			scriptCount = 1;
+		// TODO: hardcoded action hacks
 		//TODO: add stuff here that overrides actions (like Panic, etc)
-		changed |= ((Actor *) this)->OverrideActions();
+		changed |= act->OverrideActions();
 	}
 
 	bool continuing = false, done = false;
@@ -416,16 +408,16 @@ void Scriptable::ExecuteScript(int scriptCount)
 	if (changed)
 		InitTriggers();
 
-	if (Type == ST_ACTOR) {
+	if (act) {
 		//TODO: add stuff here about idle actions
-		((Actor *) this)->IdleActions(CurrentAction!=NULL);
+		act->IdleActions(CurrentAction!=NULL);
 	}
 }
 
 void Scriptable::AddAction(Action* aC)
 {
 	if (!aC) {
-		print("[GameScript]: NULL action encountered for %s!", scriptName);
+		Log(WARNING, "Scriptable", "NULL action encountered for %s!", scriptName);
 		return;
 	}
 
@@ -455,7 +447,7 @@ void Scriptable::AddAction(Action* aC)
 void Scriptable::AddActionInFront(Action* aC)
 {
 	if (!aC) {
-		print("[GameScript]: NULL action encountered for %s!", scriptName);
+		Log(WARNING, "Scriptable", "NULL action encountered for %s!", scriptName);
 		return;
 	}
 	InternalFlags|=IF_ACTIVE;
@@ -493,6 +485,7 @@ void Scriptable::ClearActions()
 	WaitCounter = 0;
 	LastTarget = 0;
 	LastTargetPos.empty();
+	LastSpellTarget = 0;
 
 	if (Type == ST_ACTOR) {
 		Interrupt();
@@ -532,7 +525,7 @@ void Scriptable::ProcessActions()
 		CurrentActionInterruptable = true;
 		if (!CurrentAction) {
 			if (! (CurrentActionTicks == 0 && CurrentActionState == 0)) {
-				print("Last action: %d", lastAction);
+				Log(ERROR, "Scriptable", "Last action: %d", lastAction);
 			}
 			assert(CurrentActionTicks == 0 && CurrentActionState == 0);
 			CurrentAction = PopNextAction();
@@ -803,7 +796,7 @@ void Scriptable::CreateProjectile(const ieResRef SpellResRef, ieDword tgt, int l
 						}
 					}
 					if (tgt) {
-						LastTarget = newact->GetGlobalID();
+						LastSpellTarget = newact->GetGlobalID();
 						LastTargetPos = newact->Pos;
 					} else {
 						// no better idea; I wonder if the original randomized point targets at all
@@ -937,8 +930,8 @@ void Scriptable::SendTriggerToAll(TriggerEntry entry)
 inline void Scriptable::ResetCastingState(Actor *caster) {
 	SpellHeader = -1;
 	SpellResRef[0] = 0;
-	LastTarget = 0;
 	LastTargetPos.empty();
+	LastSpellTarget = 0;
 	if (caster) {
 		memset(&(caster->wildSurgeMods), 0, sizeof(caster->wildSurgeMods));
 	}
@@ -996,6 +989,7 @@ void Scriptable::CastSpellPointEnd(int level, int no_stance)
 	CreateProjectile(SpellResRef, 0, level, false);
 	//FIXME: this trigger affects actors whom the caster sees, not just the caster itself
 	// the original engine saves lasttrigger only in case of SpellCast, so we have to differentiate
+	// NOTE: unused in iwd2, so the fact that it has no stored spelltype is of no consequence
 	ieDword spellID = ResolveSpellNumber(SpellResRef);
 	switch (nSpellType) {
 	case 1:
@@ -1038,10 +1032,10 @@ void Scriptable::CastSpellEnd(int level, int no_stance)
 	}
 
 	if (SpellHeader == -1) {
-		LastTarget = 0;
+		LastSpellTarget = 0;
 		return;
 	}
-	if (!LastTarget) {
+	if (!LastSpellTarget) {
 		SpellHeader = -1;
 		return;
 	}
@@ -1059,9 +1053,10 @@ void Scriptable::CastSpellEnd(int level, int no_stance)
 	}
 
 	//if the projectile doesn't need to follow the target, then use the target position
-	CreateProjectile(SpellResRef, LastTarget, level, GetSpellDistance(SpellResRef, this)==0xffffffff);
+	CreateProjectile(SpellResRef, LastSpellTarget, level, GetSpellDistance(SpellResRef, this)==0xffffffff);
 	//FIXME: this trigger affects actors whom the caster sees, not just the caster itself
 	// the original engine saves lasttrigger only in case of SpellCast, so we have to differentiate
+	// NOTE: unused in iwd2, so the fact that it has no stored spelltype is of no consequence
 	ieDword spellID = ResolveSpellNumber(SpellResRef);
 	switch (nSpellType) {
 	case 1:
@@ -1076,7 +1071,7 @@ void Scriptable::CastSpellEnd(int level, int no_stance)
 	}
 
 	// TODO: maybe it should be set on effect application, since the data uses it with dispel magic and true sight a lot
-	Actor *target = area->GetActorByGlobalID(LastTarget);
+	Actor *target = area->GetActorByGlobalID(LastSpellTarget);
 	if (target) {
 		target->AddTrigger(TriggerEntry(trigger_spellcastonme, GetGlobalID(), spellID));
 		target->LastSpellOnMe = spellID;
@@ -1097,7 +1092,6 @@ int Scriptable::CanCast(const ieResRef SpellResRef, bool verbose) {
 	// check for area dead magic
 	// tob AR3004 is a dead magic area, but using a script with personal dead magic
 	if (area->GetInternalFlag()&AF_DEADMAGIC) {
-		// TODO: display fizzling animation
 		displaymsg->DisplayConstantStringName(STR_DEADMAGIC_FAIL, DMC_WHITE, this);
 		return 0;
 	}
@@ -1161,12 +1155,17 @@ int Scriptable::CanCast(const ieResRef SpellResRef, bool verbose) {
 			displaymsg->DisplayConstantStringName(STR_MISCASTMAGIC, DMC_WHITE, this);
 			return 0;
 		}
+
+		// iwd2: make a concentration check if needed
+		if (!actor->ConcentrationCheck()) {
+			return 0;
+		}
 	}
 
 	return 1;
 }
 
-// checks if a party-friendly actor is nearby and if so, if it reckognizes the spell
+// checks if a party-friendly actor is nearby and if so, if it recognizes the spell
 // this enemy just started casting
 void Scriptable::SpellcraftCheck(const Actor *caster, const ieResRef SpellResRef)
 {
@@ -1197,9 +1196,12 @@ void Scriptable::SpellcraftCheck(const Actor *caster, const ieResRef SpellResRef
 
 		if ((Spellcraft + IntMod) > AdjustedSpellLevel) {
 			char tmpstr[100];
-			memset(tmpstr, 0, sizeof(tmpstr));
 			// eg. .:Casts Word of Recall:.
-			snprintf(tmpstr, sizeof(tmpstr), ".:%s %s:.", core->GetString(displaymsg->GetStringReference(STR_CASTS)), core->GetString(spl->SpellName));
+			char *castmsg = core->GetString(displaymsg->GetStringReference(STR_CASTS));
+			char *spellname = core->GetString(spl->SpellName);
+			snprintf(tmpstr, sizeof(tmpstr), ".:%s %s:.", castmsg, spellname);
+			core->FreeString(castmsg);
+			core->FreeString(spellname);
 			DisplayHeadText(tmpstr);
 			displaymsg->DisplayRollStringName(39306, DMC_LIGHTGREY, detective, Spellcraft+IntMod, AdjustedSpellLevel, IntMod);
 			break;
@@ -1211,19 +1213,39 @@ void Scriptable::SpellcraftCheck(const Actor *caster, const ieResRef SpellResRef
 }
 
 // shortcut for internal use when there is no wait
-void Scriptable::DirectlyCastSpellPoint(const Point &target, ieResRef spellref, int level, int no_stance, bool deplete, bool instant, bool nointerrupt)
+// if any user needs casting time support, they should use Spell* actions directly
+void Scriptable::DirectlyCastSpellPoint(const Point &target, ieResRef spellref, int level, int no_stance, bool deplete)
 {
+	// save and restore the casting targets, so we don't interrupt any gui triggered casts with spells like true seeing (repeated fx_cast_spell)
+	Point TmpPos = LastTargetPos;
+	ieDword TmpTarget = LastSpellTarget;
+	int TmpHeader = SpellHeader;
+
 	SetSpellResRef(spellref);
-	CastSpellPoint(target, deplete, instant, nointerrupt);
+	CastSpellPoint(target, deplete, true, true);
 	CastSpellPointEnd(level, no_stance);
+
+	LastTargetPos = TmpPos;
+	LastSpellTarget = TmpTarget;
+	SpellHeader = TmpHeader;
 }
 
 // shortcut for internal use
-void Scriptable::DirectlyCastSpell(Scriptable *target, ieResRef spellref, int level, int no_stance, bool deplete, bool instant, bool nointerrupt)
+// if any user needs casting time support, they should use Spell* actions directly
+void Scriptable::DirectlyCastSpell(Scriptable *target, ieResRef spellref, int level, int no_stance, bool deplete)
 {
+	// save and restore the casting targets, so we don't interrupt any gui triggered casts with spells like true seeing (repeated fx_cast_spell)
+	Point TmpPos = LastTargetPos;
+	ieDword TmpTarget = LastSpellTarget;
+	int TmpHeader = SpellHeader;
+
 	SetSpellResRef(spellref);
-	CastSpell(target, deplete, instant, nointerrupt);
+	CastSpell(target, deplete, true, true);
 	CastSpellEnd(level, no_stance);
+
+	LastTargetPos = TmpPos;
+	LastSpellTarget = TmpTarget;
+	SpellHeader = TmpHeader;
 }
 
 //set target as point
@@ -1231,7 +1253,7 @@ void Scriptable::DirectlyCastSpell(Scriptable *target, ieResRef spellref, int le
 //if spell is illegal stop casting
 int Scriptable::CastSpellPoint( const Point &target, bool deplete, bool instant, bool nointerrupt )
 {
-	LastTarget = 0;
+	LastSpellTarget = 0;
 	LastTargetPos.empty();
 	Actor *actor = NULL;
 	if (Type == ST_ACTOR) {
@@ -1265,7 +1287,7 @@ int Scriptable::CastSpellPoint( const Point &target, bool deplete, bool instant,
 //if spell is illegal stop casting
 int Scriptable::CastSpell( Scriptable* target, bool deplete, bool instant, bool nointerrupt )
 {
-	LastTarget = 0;
+	LastSpellTarget = 0;
 	LastTargetPos.empty();
 	Actor *actor = NULL;
 	if (Type == ST_ACTOR) {
@@ -1288,7 +1310,7 @@ int Scriptable::CastSpell( Scriptable* target, bool deplete, bool instant, bool
 
 	LastTargetPos = target->Pos;
 	if (target->Type==ST_ACTOR) {
-		LastTarget = target->GetGlobalID();
+		LastSpellTarget = target->GetGlobalID();
 	}
 
 	if(!CheckWildSurge()) {
@@ -1474,10 +1496,10 @@ bool Scriptable::HandleHardcodedSurge(ieResRef surgeSpellRef, Spell *spl, Actor
 			tmp3 = caster->WMLevelMod; // also save caster level; the original didn't reroll the bonus
 			caster->Modified[IE_FORCESURGE] = 7;
 			caster->Modified[IE_SURGEMOD] = - caster->GetCasterLevel(spl->SpellType); // nulify the bonus
-			if (LastTarget) {
-				target = area->GetActorByGlobalID(LastTarget);
+			if (LastSpellTarget) {
+				target = area->GetActorByGlobalID(LastSpellTarget);
 				if (!target) {
-					target = core->GetGame()->GetActorByGlobalID(LastTarget);
+					target = core->GetGame()->GetActorByGlobalID(LastSpellTarget);
 				}
 			}
 			if (!LastTargetPos.isempty()) {
@@ -1773,9 +1795,7 @@ Highlightable::Highlightable(ScriptableType type)
 
 Highlightable::~Highlightable(void)
 {
-	if (outline) {
-		delete( outline );
-	}
+	delete( outline );
 }
 
 bool Highlightable::IsOver(const Point &Pos) const
@@ -1847,9 +1867,7 @@ bool Highlightable::TryUnlock(Actor *actor, bool removekey) {
 		CREItem *item = NULL;
 		haskey->inventory.RemoveItem(Key,0,&item);
 		//the item should always be existing!!!
-		if (item) {
-			delete item;
-		}
+		delete item;
 	}
 
 	return true;
@@ -1980,7 +1998,7 @@ void Movable::SetStance(unsigned int arg)
 		if (StanceID == IE_ANI_ATTACK) {
 			// Set stance to a random attack animation
 
-			int random = rand()%100;
+			int random = RAND(0, 99);
 			if (random < AttackMovements[0]) {
 				StanceID = IE_ANI_ATTACK_BACKSLASH;
 			} else if (random < AttackMovements[0] + AttackMovements[1]) {
@@ -1991,8 +2009,8 @@ void Movable::SetStance(unsigned int arg)
 		}
 
 	} else {
-		StanceID=IE_ANI_AWAKE; //
-		print("Tried to set invalid stance id(%u)", arg);
+		StanceID=IE_ANI_AWAKE;
+		Log(ERROR, "Movable", "Tried to set invalid stance id(%u)", arg);
 	}
 }
 
@@ -2015,7 +2033,7 @@ void Movable::MoveLine(int steps, int Pass, ieDword orient)
 	path = area->GetLine( p, steps, orient, Pass );
 }
 
-void AdjustPositionTowards(Point &Pos, ieDword time_diff, unsigned int walk_speed, short srcx, short srcy, short destx, short desty) {
+static void AdjustPositionTowards(Point &Pos, ieDword time_diff, unsigned int walk_speed, short srcx, short srcy, short destx, short desty) {
 	if (destx > srcx)
 		Pos.x += ( unsigned short )
 			( ( ( ( ( destx * 16 ) + 8 ) - Pos.x ) * ( time_diff ) ) / walk_speed );
@@ -2215,8 +2233,8 @@ void Movable::RandomWalk(bool can_stop, bool run)
 		return;
 	}
 	//if not continous random walk, then stops for a while
-	if (can_stop && (rand()&3) ) {
-		SetWait((rand()&7)+7);
+	if (can_stop && !RAND(0,3)) {
+		SetWait(RAND(7,14));
 		return;
 	}
 	if (run) {
