@@ -26,6 +26,8 @@
 #include "Palette.h"
 #include "SpriteCover.h"
 
+namespace GemRB {
+
 class Animation;
 class AnimationFactory;
 class DataStream;
@@ -113,7 +115,7 @@ public:
 	unsigned long starttime;
 public:
 	//draws the next frame of the videocell
-	bool Draw(const Region &screen, const Point &Pos, const Color &tint, Map *area, int dither, int orientation);
+	bool Draw(const Region &screen, const Point &Pos, const Color &tint, Map *area, int dither, int orientation, int height);
 	//sets phase (0-2)
 	void SetPhase(int arg);
 	//sets sound for phase (p_onset, p_hold, p_release)
@@ -135,7 +137,7 @@ public:
 	/* sets up a delay in the beginning of the vvc */
 	void SetDelay(ieDword delay);
 	/* sets default duration if it wasn't set yet */
-	void SetDefaultDuration(unsigned int duration);
+	void SetDefaultDuration(ieDword duration);
 	/* sets up the direction of the vvc */
 	void SetOrientation(int orientation);
 	/* transforms vvc to blended */
@@ -155,4 +157,6 @@ private:
 	void GetPaletteCopy();
 };
 
+}
+
 #endif
