@@ -32,6 +32,8 @@
 #include "Store.h"
 #include "System/DataStream.h"
 
+namespace GemRB {
+
 /**
  * @class StoreMgr
  * Abstract loader for Store objects
@@ -41,11 +43,12 @@ class GEM_EXPORT StoreMgr : public Plugin {
 public:
 	StoreMgr(void);
 	virtual ~StoreMgr(void);
-	virtual bool Open(DataStream* stream, bool autoFree = true) = 0;
+	virtual bool Open(DataStream* stream) = 0;
 	virtual Store* GetStore(Store *s) = 0;
 
-	virtual int GetStoredFileSize(Store *s) = 0;
-	virtual int PutStore(DataStream* stream, Store *s) = 0;
+	virtual bool PutStore(DataStream* stream, Store *s) = 0;
 };
 
+}
+
 #endif
