@@ -36,6 +36,8 @@
 
 #include <vector>
 
+namespace GemRB {
+
 /** Area is visible on WorldMap */
 #define WMP_ENTRY_VISIBLE    0x1
 /** Area is visible on WorldMap only when party is in adjacent area */
@@ -70,7 +72,9 @@ public:
 	void SetAreaStatus(ieDword status, int op);
 
 	//! return the map icon of this location. Free the sprite afterwards.
-	Sprite2D *GetMapIcon(AnimationFactory *bam);
+	Sprite2D *GetMapIcon(AnimationFactory *bam, bool overridePalette);
+	// note that this is only valid after GetMapIcon has been called
+	bool HighlightSelected() const { return SingleFrame; }
 	const char* GetCaption();
 	const char* GetTooltip();
 private:
@@ -78,12 +82,13 @@ private:
 	Sprite2D *MapIcon;
 	char *StrCaption;
 	char *StrTooltip;
+	bool SingleFrame;
 
 	void SetPalette(int gradient, Sprite2D *MapIcon);
 public:
 	ieResRef AreaName;
 	ieResRef AreaResRef;
-	char AreaLongName[32];
+	ieVariable AreaLongName;
 	ieDword IconSeq;
 	ieDword X;
 	ieDword Y;
@@ -101,7 +106,7 @@ public:
 
 struct WMPAreaLink {
 	ieDword AreaIndex;
-	char DestEntryPoint[32];
+	ieVariable DestEntryPoint;
 	ieDword DistanceScale;
 	ieDword DirectionFlags; //where will the player appear on dest. area
 	ieResRef EncounterAreaResRef[5];
@@ -126,10 +131,6 @@ public: //struct members
 	ieStrRef AreaName;
 	ieDword unknown1;
 	ieDword unknown2;
-	ieDword AreaEntriesCount;
-	ieDword AreaEntriesOffset;
-	ieDword AreaLinksOffset;
-	ieDword AreaLinksCount;
 	ieResRef MapIconResRef;
 
 	AnimationFactory *bam;
@@ -139,6 +140,7 @@ private: //non-struct members
 	std::vector< WMPAreaLink*> area_links;
 	int *Distances;
 	int *GotHereFrom;
+	int encounterArea;
 public:
 	void SetMapIcons(AnimationFactory *bam);
 	Sprite2D* GetMapMOS() const { return MapMOS; }
@@ -169,6 +171,8 @@ public:
 	WMPAreaEntry* GetArea(const ieResRef AreaName, unsigned int &i) const;
 	/** Finds an area name closest to the given area */
 	WMPAreaEntry* FindNearestEntry(const ieResRef AreaName, unsigned int &i) const;
+	void SetEncounterArea(const ieResRef area, WMPAreaLink *link);
+	void ClearEncounterArea();
 private:
 	/** updates visibility of adjacent areas, called from CalculateDistances */
 	void UpdateAreaVisibility(const ieResRef AreaName, int direction);
@@ -202,4 +206,6 @@ public:
 	unsigned int FindAndSetCurrentMap(const ieResRef area);
 };
 
+}
+
 #endif // ! WORLDMAP_H
