@@ -197,7 +197,7 @@ static int magcount=-1;
 
 static int IsDomain(ieResRef name, unsigned short &level, unsigned int kit)
 {
-	for(int i=0;i<domcount;i++) {
+	for(int i=0;i<splcount;i++) {
 		if (domlist[i].Equals(name) ) {
 			level = domlist[i].FindSpell(kit);
 				return i;
@@ -206,7 +206,7 @@ static int IsDomain(ieResRef name, unsigned short &level, unsigned int kit)
 	return -1;
 }
 
-static int IsSpecial(ieResRef name, unsigned short &level, unsigned int kit)
+/*static int IsSpecial(ieResRef name, unsigned short &level, unsigned int kit)
 {
 	for(int i=0;i<magcount;i++) {
 		if (maglist[i].Equals(name) ) {
@@ -215,21 +215,7 @@ static int IsSpecial(ieResRef name, unsigned short &level, unsigned int kit)
 		}
 	}
 	return -1;
-}
-
-static int SpellType(ieResRef name, unsigned short &level, unsigned int clsmsk)
-{
-	for (int i = 0;i<splcount;i++) {
-		if (spllist[i].Equals(name) ) {
-			for(int type=0;type<7;type++) {
-				if (clsmsk & i) {
-					level = spllist[i].FindSpell(type);
-				}
-			}
-		}
-	}
-	return 0;
-}
+}*/
 
 int CREImporter::FindSpellType(char *name, unsigned short &level, unsigned int clsmsk, unsigned int kit) const
 {
@@ -237,13 +223,33 @@ int CREImporter::FindSpellType(char *name, unsigned short &level, unsigned int c
 	if (IsSong(name)>=0) return IE_IWD2_SPELL_SONG;
 	if (IsShape(name)>=0) return IE_IWD2_SPELL_SHAPE;
 	if (IsInnate(name)>=0) return IE_IWD2_SPELL_INNATE;
+// there is no gui page for specialists spells, so let's skip them here
+// otherwise their overlap causes bards and sorcerers to have their spells
+// on the wizard page
+//	if (IsSpecial(name, level, kit)>=0) return IE_IWD2_SPELL_WIZARD;
+
+	// try harder for the rest
+	for (int i = 0;i<splcount;i++) {
+		if (spllist[i].Equals(name) ) {
+			// iterate over table columns ("kits" - book types)
+			for(int type = IE_IWD2_SPELL_BARD; type < IE_IWD2_SPELL_DOMAIN; type++) {
+				if (clsmsk & (1<<type)) {
+					level = spllist[i].FindSpell(type);
+					// FIXME: returning the first will misplace spells for multiclasses
+					return type;
+				}
+			}
+		}
+	}
 	if (IsDomain(name, level, kit)>=0) return IE_IWD2_SPELL_DOMAIN;
-	if (IsSpecial(name, level, kit)>=0) return IE_IWD2_SPELL_WIZARD;
-	return SpellType(name, level, clsmsk);
+
+	Log(ERROR, "CREImporter", "Could not find spell (%s) booktype! %d, %d!", name, clsmsk, kit);
+	// pseudorandom fallback
+	return IE_IWD2_SPELL_WIZARD;
 }
 
 //int CREImporter::ResolveSpellName(ieResRef name, int level, ieIWD2SpellType type) const
-int ResolveSpellName(ieResRef name, int level, ieIWD2SpellType type)
+static int ResolveSpellName(ieResRef name, int level, ieIWD2SpellType type)
 {
 	int i;
 
@@ -640,7 +646,7 @@ void CREImporter::WriteChrHeader(DataStream *stream, Actor *act)
 	stream->Write( Signature, 8);
 	memset( Signature,0,sizeof(Signature));
 	memset( name,0,sizeof(name));
-	strncpy( name, act->GetName(0), sizeof(name) );
+	strlcpy(name, act->GetName(0), sizeof(name));
 	stream->Write( name, 32);
 
 	stream->WriteDword( &tmpDword); //cre offset (chr header size)
@@ -2268,20 +2274,10 @@ int CREImporter::GetStoredFileSize(Actor *actor)
 		MemorizedSpellsCount = actor->spellbook.GetTotalMemorizedSpellsCount();
 		headersize += MemorizedSpellsCount * 12;
 	}
-	EffectsOffset = headersize;
+	ItemSlotsOffset = headersize;
 
-	//adding effects
-	EffectsCount = actor->fxqueue.GetSavedEffectsCount();
-	VariablesCount = actor->locals->GetCount();
-	if (VariablesCount) {
-		TotSCEFF=1;
-	}
-	if (TotSCEFF) {
-		headersize += (VariablesCount + EffectsCount) * 264;
-	} else {
-		//if there are variables, then TotSCEFF is set
-		headersize += EffectsCount * 48;
-	}
+	//adding itemslot table size and equipped slot fields
+	headersize += (Inventory_Size) * sizeof(ieWord) + sizeof(ieWord) * 2;
 	ItemsOffset = headersize;
 
 	//counting items (calculating item storage)
@@ -2294,10 +2290,22 @@ int CREImporter::GetStoredFileSize(Actor *actor)
 		}
 	}
 	headersize += ItemsCount * 20;
-	ItemSlotsOffset = headersize;
 
-	//adding itemslot table size and equipped slot fields
-	return headersize + (Inventory_Size)*sizeof(ieWord)+sizeof(ieWord)*2;
+	EffectsOffset = headersize;
+	//adding effects
+	EffectsCount = actor->fxqueue.GetSavedEffectsCount();
+	VariablesCount = actor->locals->GetCount();
+	if (VariablesCount) {
+		TotSCEFF=1;
+	}
+	if (TotSCEFF) {
+		headersize += (VariablesCount + EffectsCount) * 264;
+	} else {
+		//if there are variables, then TotSCEFF is set
+		headersize += EffectsCount * 48;
+	}
+
+	return headersize;
 }
 
 int CREImporter::PutInventory(DataStream *stream, Actor *actor, unsigned int size)
@@ -2312,6 +2320,21 @@ int CREImporter::PutInventory(DataStream *stream, Actor *actor, unsigned int siz
 		indices[i]=(ieWord) -1;
 	}
 
+	for (i=0;i<size;i++) {
+		//ignore first element, getinventorysize makes space for fist
+		unsigned int j = core->QuerySlot(i+1);
+		CREItem *it = actor->inventory.GetSlotItem( j );
+		if (it) {
+			indices[i] = ItemCount++;
+		}
+		stream->WriteWord( indices+i);
+	}
+	free(indices);
+	tmpWord = (ieWord) actor->inventory.GetEquipped();
+	stream->WriteWord( &tmpWord);
+	tmpWord = (ieWord) actor->inventory.GetEquippedHeader();
+	stream->WriteWord( &tmpWord);
+
 	for (i=0;i<size;i++) {
 		//ignore first element, getinventorysize makes space for fist
 		unsigned int j = core->QuerySlot(i+1);
@@ -2334,16 +2357,7 @@ int CREImporter::PutInventory(DataStream *stream, Actor *actor, unsigned int siz
 			}
 		}
 		stream->WriteDword( &tmpDword);
-		indices[i] = ItemCount++;
 	}
-	for (i=0;i<size;i++) {
-		stream->WriteWord( indices+i);
-	}
-	tmpWord = (ieWord) actor->inventory.GetEquipped();
-	stream->WriteWord( &tmpWord);
-	tmpWord = (ieWord) actor->inventory.GetEquippedHeader();
-	stream->WriteWord( &tmpWord);
-	free(indices);
 	return 0;
 }
 
@@ -2667,7 +2681,7 @@ int CREImporter::PutHeader(DataStream *stream, Actor *actor)
 		tmpByte = actor->BaseStats[IE_MORALERECOVERYTIME];
 		stream->Write( &tmpByte, 1);
 		// unknown byte
-		stream->Write( &Signature,1);
+		stream->Write( &filling, 1);
 		tmpDword = ((actor->BaseStats[IE_KIT] & 0xffff) << 16) +
 			((actor->BaseStats[IE_KIT] & 0xffff0000) >> 16);
 		stream->WriteDword( &tmpDword );
@@ -3213,6 +3227,13 @@ int CREImporter::PutActor(DataStream *stream, Actor *actor, bool chr)
 		}
 	}
 
+	//items and inventory slots
+	assert(stream->GetPos() == CREOffset+ItemSlotsOffset);
+	ret = PutInventory( stream, actor, Inventory_Size);
+	if (ret) {
+		return ret;
+	}
+
 	assert(stream->GetPos() == CREOffset+EffectsOffset);
 	ret = PutEffects(stream, actor);
 	if (ret) {
@@ -3224,12 +3245,6 @@ int CREImporter::PutActor(DataStream *stream, Actor *actor, bool chr)
 		return ret;
 	}
 
-	//items and inventory slots
-	assert(stream->GetPos() == CREOffset+ItemsOffset);
-	ret = PutInventory( stream, actor, Inventory_Size);
-	if (ret) {
-		return ret;
-	}
 	return 0;
 }
 
