@@ -30,6 +30,8 @@
 #endif
 #include <vorbis/vorbisfile.h>
 
+namespace GemRB {
+
 class OGGReader : public SoundMgr {
 private:
 	OggVorbis_File OggStream;
@@ -52,4 +54,6 @@ public:
 	int read_samples(short* buffer, int count);
 };
 
+}
+
 #endif
