@@ -23,12 +23,14 @@
 
 #include "SoundMgr.h"
 
-#include "DataStream.h"
+#include "System/DataStream.h"
 
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
 
+namespace GemRB {
+
 // RAW file reader
 class RawPCMReader : public SoundMgr {
 protected:
@@ -56,4 +58,6 @@ public:
 	bool Open(DataStream* stream);
 };
 
+}
+
 #endif
